from typing import Any, ClassVar, Dict, List, Optional

from typing import overload

class CDynamicGrid3D_mrpt_maps_TRandomFieldVoxel_double_t:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float, arg2: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float, arg2: float, arg3: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float, arg2: float, arg3: float, arg4: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float, arg2: float, arg3: float, arg4: float, arg5: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float, arg2: float, arg3: float, arg4: float, arg5: float, arg6: float) -> None: ...
    @overload
    def __init__(self, x_min: float, x_max: float, y_min: float, y_max: float, z_min: float, z_max: float, resolution_xy: float, resolution_z: float) -> None: ...
    @overload
    def __init__(self, arg0: CDynamicGrid3D_mrpt_maps_TRandomFieldVoxel_double_t) -> None: ...
    @overload
    def __init__(self, arg0: CDynamicGrid3D_mrpt_maps_TRandomFieldVoxel_double_t) -> None: ...
    def assign(self) -> CDynamicGrid3D_mrpt_maps_TRandomFieldVoxel_double_t: ...
    def cellAbsIndexFromCXCYCZ(self, cx: int, cy: int, cz: int) -> int: ...
    def cellByIndex(self, *args, **kwargs) -> Any: ...
    def cellByPos(self, *args, **kwargs) -> Any: ...
    def cellRefByPos(self, *args, **kwargs) -> Any: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    @overload
    def fill(self, value) -> None: ...
    @overload
    def fill(conststructmrpt) -> void: ...
    @overload
    def getResolutionXY(self) -> float: ...
    @overload
    def getResolutionXY() -> double: ...
    @overload
    def getResolutionZ(self) -> float: ...
    @overload
    def getResolutionZ() -> double: ...
    @overload
    def getSizeX(self) -> int: ...
    @overload
    def getSizeX() -> size_t: ...
    @overload
    def getSizeY(self) -> int: ...
    @overload
    def getSizeY() -> size_t: ...
    @overload
    def getSizeZ(self) -> int: ...
    @overload
    def getSizeZ() -> size_t: ...
    @overload
    def getVoxelCount(self) -> int: ...
    @overload
    def getVoxelCount() -> size_t: ...
    @overload
    def getXMax(self) -> float: ...
    @overload
    def getXMax() -> double: ...
    @overload
    def getXMin(self) -> float: ...
    @overload
    def getXMin() -> double: ...
    @overload
    def getYMax(self) -> float: ...
    @overload
    def getYMax() -> double: ...
    @overload
    def getYMin(self) -> float: ...
    @overload
    def getYMin() -> double: ...
    @overload
    def getZMax(self) -> float: ...
    @overload
    def getZMax() -> double: ...
    @overload
    def getZMin(self) -> float: ...
    @overload
    def getZMin() -> double: ...
    @overload
    def idx2x(self, cx: int) -> float: ...
    @overload
    def idx2x(int) -> double: ...
    @overload
    def idx2y(self, cy: int) -> float: ...
    @overload
    def idx2y(int) -> double: ...
    @overload
    def idx2z(self, cz: int) -> float: ...
    @overload
    def idx2z(int) -> double: ...
    def isOutOfBounds(self, cx: int, cy: int, cz: int) -> bool: ...
    @overload
    def resize(self, new_x_min: float, new_x_max: float, new_y_min: float, new_y_max: float, new_z_min: float, new_z_max: float, defaultValueNewCells) -> None: ...
    @overload
    def resize(self, new_x_min: float, new_x_max: float, new_y_min: float, new_y_max: float, new_z_min: float, new_z_max: float, defaultValueNewCells, additionalMarginMeters: float) -> None: ...
    @overload
    def setSize(self, x_min: float, x_max: float, y_min: float, y_max: float, z_min: float, z_max: float, resolution_xy: float) -> None: ...
    @overload
    def setSize(self, x_min: float, x_max: float, y_min: float, y_max: float, z_min: float, z_max: float, resolution_xy: float, resolution_z_: float) -> None: ...
    @overload
    def setSize(self, x_min: float, x_max: float, y_min: float, y_max: float, z_min: float, z_max: float, resolution_xy: float, resolution_z_: float, fill_value) -> None: ...
    @overload
    def x2idx(self, x: float) -> int: ...
    @overload
    def x2idx(double) -> int: ...
    @overload
    def y2idx(self, y: float) -> int: ...
    @overload
    def y2idx(double) -> int: ...
    @overload
    def z2idx(self, z: float) -> int: ...
    @overload
    def z2idx(double) -> int: ...

class CDynamicGrid3D_signed_char_double_t:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float, arg2: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float, arg2: float, arg3: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float, arg2: float, arg3: float, arg4: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float, arg2: float, arg3: float, arg4: float, arg5: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float, arg2: float, arg3: float, arg4: float, arg5: float, arg6: float) -> None: ...
    @overload
    def __init__(self, x_min: float, x_max: float, y_min: float, y_max: float, z_min: float, z_max: float, resolution_xy: float, resolution_z: float) -> None: ...
    @overload
    def __init__(self, arg0: CDynamicGrid3D_signed_char_double_t) -> None: ...
    @overload
    def __init__(self, arg0: CDynamicGrid3D_signed_char_double_t) -> None: ...
    def assign(self) -> CDynamicGrid3D_signed_char_double_t: ...
    def cellAbsIndexFromCXCYCZ(self, cx: int, cy: int, cz: int) -> int: ...
    @overload
    def cellByIndex(self, cx: int, cy: int, cz: int) -> int: ...
    @overload
    def cellByIndex(self, cidx: int) -> int: ...
    def cellByPos(self, x: float, y: float, z: float) -> int: ...
    def cellRefByPos(self, x: float, y: float, z: float) -> int: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    def fill(self, value: int) -> None: ...
    @overload
    def getResolutionXY(self) -> float: ...
    @overload
    def getResolutionXY() -> double: ...
    @overload
    def getResolutionZ(self) -> float: ...
    @overload
    def getResolutionZ() -> double: ...
    @overload
    def getSizeX(self) -> int: ...
    @overload
    def getSizeX() -> size_t: ...
    @overload
    def getSizeY(self) -> int: ...
    @overload
    def getSizeY() -> size_t: ...
    @overload
    def getSizeZ(self) -> int: ...
    @overload
    def getSizeZ() -> size_t: ...
    @overload
    def getVoxelCount(self) -> int: ...
    @overload
    def getVoxelCount() -> size_t: ...
    @overload
    def getXMax(self) -> float: ...
    @overload
    def getXMax() -> double: ...
    @overload
    def getXMin(self) -> float: ...
    @overload
    def getXMin() -> double: ...
    @overload
    def getYMax(self) -> float: ...
    @overload
    def getYMax() -> double: ...
    @overload
    def getYMin(self) -> float: ...
    @overload
    def getYMin() -> double: ...
    @overload
    def getZMax(self) -> float: ...
    @overload
    def getZMax() -> double: ...
    @overload
    def getZMin(self) -> float: ...
    @overload
    def getZMin() -> double: ...
    @overload
    def idx2x(self, cx: int) -> float: ...
    @overload
    def idx2x(int) -> double: ...
    @overload
    def idx2y(self, cy: int) -> float: ...
    @overload
    def idx2y(int) -> double: ...
    @overload
    def idx2z(self, cz: int) -> float: ...
    @overload
    def idx2z(int) -> double: ...
    def isOutOfBounds(self, cx: int, cy: int, cz: int) -> bool: ...
    @overload
    def resize(self, new_x_min: float, new_x_max: float, new_y_min: float, new_y_max: float, new_z_min: float, new_z_max: float, defaultValueNewCells: int) -> None: ...
    @overload
    def resize(self, new_x_min: float, new_x_max: float, new_y_min: float, new_y_max: float, new_z_min: float, new_z_max: float, defaultValueNewCells: int, additionalMarginMeters: float) -> None: ...
    @overload
    def setSize(self, x_min: float, x_max: float, y_min: float, y_max: float, z_min: float, z_max: float, resolution_xy: float) -> None: ...
    @overload
    def setSize(self, x_min: float, x_max: float, y_min: float, y_max: float, z_min: float, z_max: float, resolution_xy: float, resolution_z_: float) -> None: ...
    @overload
    def setSize(self, x_min: float, x_max: float, y_min: float, y_max: float, z_min: float, z_max: float, resolution_xy: float, resolution_z_: float, fill_value: int) -> None: ...
    @overload
    def x2idx(self, x: float) -> int: ...
    @overload
    def x2idx(double) -> int: ...
    @overload
    def y2idx(self, y: float) -> int: ...
    @overload
    def y2idx(double) -> int: ...
    @overload
    def z2idx(self, z: float) -> int: ...
    @overload
    def z2idx(double) -> int: ...

class CDynamicGrid_double_t:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float, arg2: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float, arg2: float, arg3: float) -> None: ...
    @overload
    def __init__(self, x_min: float, x_max: float, y_min: float, y_max: float, resolution: float) -> None: ...
    @overload
    def __init__(self, arg0: CDynamicGrid_double_t) -> None: ...
    @overload
    def __init__(self, arg0: CDynamicGrid_double_t) -> None: ...
    def assign(self) -> CDynamicGrid_double_t: ...
    def cell2float(self) -> float: ...
    def cellByIndex(self, cx: int, cy: int) -> float: ...
    def cellByPos(self, x: float, y: float) -> float: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    def fill(self, value: float) -> None: ...
    @overload
    def getResolution(self) -> float: ...
    @overload
    def getResolution() -> double: ...
    @overload
    def getSizeX(self) -> int: ...
    @overload
    def getSizeX() -> size_t: ...
    @overload
    def getSizeY(self) -> int: ...
    @overload
    def getSizeY() -> size_t: ...
    @overload
    def getXMax(self) -> float: ...
    @overload
    def getXMax() -> double: ...
    @overload
    def getXMin(self) -> float: ...
    @overload
    def getXMin() -> double: ...
    @overload
    def getYMax(self) -> float: ...
    @overload
    def getYMax() -> double: ...
    @overload
    def getYMin(self) -> float: ...
    @overload
    def getYMin() -> double: ...
    def idx2cxcy(self, idx: int, cx: int, cy: int) -> None: ...
    @overload
    def idx2x(self, cx: int) -> float: ...
    @overload
    def idx2x(int) -> double: ...
    @overload
    def idx2y(self, cy: int) -> float: ...
    @overload
    def idx2y(int) -> double: ...
    @overload
    def resize(self, new_x_min: float, new_x_max: float, new_y_min: float, new_y_max: float, defaultValueNewCells: float) -> None: ...
    @overload
    def resize(self, new_x_min: float, new_x_max: float, new_y_min: float, new_y_max: float, defaultValueNewCells: float, additionalMarginMeters: float) -> None: ...
    @overload
    def saveToTextFile(self, fileName: str) -> bool: ...
    @overload
    def saveToTextFile(conststd) -> bool: ...
    @overload
    def setSize(self, x_min: float, x_max: float, y_min: float, y_max: float, resolution: float) -> None: ...
    @overload
    def setSize(self, x_min: float, x_max: float, y_min: float, y_max: float, resolution: float, fill_value: float) -> None: ...
    @overload
    def x2idx(self, x: float) -> int: ...
    @overload
    def x2idx(double) -> int: ...
    def xy2idx(self, x: float, y: float) -> int: ...
    @overload
    def y2idx(self, y: float) -> int: ...
    @overload
    def y2idx(double) -> int: ...

class CDynamicGrid_mrpt_maps_THeightGridmapCell_t:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float, arg2: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float, arg2: float, arg3: float) -> None: ...
    @overload
    def __init__(self, x_min: float, x_max: float, y_min: float, y_max: float, resolution: float) -> None: ...
    @overload
    def __init__(self, arg0: CDynamicGrid_mrpt_maps_THeightGridmapCell_t) -> None: ...
    @overload
    def __init__(self, arg0: CDynamicGrid_mrpt_maps_THeightGridmapCell_t) -> None: ...
    def assign(self) -> CDynamicGrid_mrpt_maps_THeightGridmapCell_t: ...
    @overload
    def cell2float(self) -> float: ...
    @overload
    def cell2float(conststructmrpt) -> float: ...
    def cellByIndex(self, *args, **kwargs) -> Any: ...
    def cellByPos(self, *args, **kwargs) -> Any: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    @overload
    def fill(self, value) -> None: ...
    @overload
    def fill(conststructmrpt) -> void: ...
    @overload
    def getResolution(self) -> float: ...
    @overload
    def getResolution() -> double: ...
    @overload
    def getSizeX(self) -> int: ...
    @overload
    def getSizeX() -> size_t: ...
    @overload
    def getSizeY(self) -> int: ...
    @overload
    def getSizeY() -> size_t: ...
    @overload
    def getXMax(self) -> float: ...
    @overload
    def getXMax() -> double: ...
    @overload
    def getXMin(self) -> float: ...
    @overload
    def getXMin() -> double: ...
    @overload
    def getYMax(self) -> float: ...
    @overload
    def getYMax() -> double: ...
    @overload
    def getYMin(self) -> float: ...
    @overload
    def getYMin() -> double: ...
    def idx2cxcy(self, idx: int, cx: int, cy: int) -> None: ...
    @overload
    def idx2x(self, cx: int) -> float: ...
    @overload
    def idx2x(int) -> double: ...
    @overload
    def idx2y(self, cy: int) -> float: ...
    @overload
    def idx2y(int) -> double: ...
    @overload
    def resize(self, new_x_min: float, new_x_max: float, new_y_min: float, new_y_max: float, defaultValueNewCells) -> None: ...
    @overload
    def resize(self, new_x_min: float, new_x_max: float, new_y_min: float, new_y_max: float, defaultValueNewCells, additionalMarginMeters: float) -> None: ...
    @overload
    def saveToTextFile(self, fileName: str) -> bool: ...
    @overload
    def saveToTextFile(conststd) -> bool: ...
    @overload
    def setSize(self, x_min: float, x_max: float, y_min: float, y_max: float, resolution: float) -> None: ...
    @overload
    def setSize(self, x_min: float, x_max: float, y_min: float, y_max: float, resolution: float, fill_value) -> None: ...
    @overload
    def x2idx(self, x: float) -> int: ...
    @overload
    def x2idx(double) -> int: ...
    def xy2idx(self, x: float, y: float) -> int: ...
    @overload
    def y2idx(self, y: float) -> int: ...
    @overload
    def y2idx(double) -> int: ...

class CDynamicGrid_mrpt_maps_TRandomFieldCell_t:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float, arg2: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float, arg2: float, arg3: float) -> None: ...
    @overload
    def __init__(self, x_min: float, x_max: float, y_min: float, y_max: float, resolution: float) -> None: ...
    @overload
    def __init__(self, arg0: CDynamicGrid_mrpt_maps_TRandomFieldCell_t) -> None: ...
    @overload
    def __init__(self, arg0: CDynamicGrid_mrpt_maps_TRandomFieldCell_t) -> None: ...
    def assign(self) -> CDynamicGrid_mrpt_maps_TRandomFieldCell_t: ...
    @overload
    def cell2float(self) -> float: ...
    @overload
    def cell2float(conststructmrpt) -> float: ...
    def cellByIndex(self, *args, **kwargs) -> Any: ...
    def cellByPos(self, *args, **kwargs) -> Any: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    @overload
    def fill(self, value) -> None: ...
    @overload
    def fill(conststructmrpt) -> void: ...
    @overload
    def getResolution(self) -> float: ...
    @overload
    def getResolution() -> double: ...
    @overload
    def getSizeX(self) -> int: ...
    @overload
    def getSizeX() -> size_t: ...
    @overload
    def getSizeY(self) -> int: ...
    @overload
    def getSizeY() -> size_t: ...
    @overload
    def getXMax(self) -> float: ...
    @overload
    def getXMax() -> double: ...
    @overload
    def getXMin(self) -> float: ...
    @overload
    def getXMin() -> double: ...
    @overload
    def getYMax(self) -> float: ...
    @overload
    def getYMax() -> double: ...
    @overload
    def getYMin(self) -> float: ...
    @overload
    def getYMin() -> double: ...
    def idx2cxcy(self, idx: int, cx: int, cy: int) -> None: ...
    @overload
    def idx2x(self, cx: int) -> float: ...
    @overload
    def idx2x(int) -> double: ...
    @overload
    def idx2y(self, cy: int) -> float: ...
    @overload
    def idx2y(int) -> double: ...
    @overload
    def resize(self, new_x_min: float, new_x_max: float, new_y_min: float, new_y_max: float, defaultValueNewCells) -> None: ...
    @overload
    def resize(self, new_x_min: float, new_x_max: float, new_y_min: float, new_y_max: float, defaultValueNewCells, additionalMarginMeters: float) -> None: ...
    @overload
    def saveToTextFile(self, fileName: str) -> bool: ...
    @overload
    def saveToTextFile(conststd) -> bool: ...
    @overload
    def setSize(self, x_min: float, x_max: float, y_min: float, y_max: float, resolution: float) -> None: ...
    @overload
    def setSize(self, x_min: float, x_max: float, y_min: float, y_max: float, resolution: float, fill_value) -> None: ...
    @overload
    def x2idx(self, x: float) -> int: ...
    @overload
    def x2idx(double) -> int: ...
    def xy2idx(self, x: float, y: float) -> int: ...
    @overload
    def y2idx(self, y: float) -> int: ...
    @overload
    def y2idx(double) -> int: ...

class CDynamicGrid_signed_char_t:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float, arg2: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float, arg2: float, arg3: float) -> None: ...
    @overload
    def __init__(self, x_min: float, x_max: float, y_min: float, y_max: float, resolution: float) -> None: ...
    @overload
    def __init__(self, arg0: CDynamicGrid_signed_char_t) -> None: ...
    @overload
    def __init__(self, arg0: CDynamicGrid_signed_char_t) -> None: ...
    def assign(self) -> CDynamicGrid_signed_char_t: ...
    def cell2float(self) -> float: ...
    def cellByIndex(self, cx: int, cy: int) -> int: ...
    def cellByPos(self, x: float, y: float) -> int: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    def fill(self, value: int) -> None: ...
    @overload
    def getResolution(self) -> float: ...
    @overload
    def getResolution() -> double: ...
    @overload
    def getSizeX(self) -> int: ...
    @overload
    def getSizeX() -> size_t: ...
    @overload
    def getSizeY(self) -> int: ...
    @overload
    def getSizeY() -> size_t: ...
    @overload
    def getXMax(self) -> float: ...
    @overload
    def getXMax() -> double: ...
    @overload
    def getXMin(self) -> float: ...
    @overload
    def getXMin() -> double: ...
    @overload
    def getYMax(self) -> float: ...
    @overload
    def getYMax() -> double: ...
    @overload
    def getYMin(self) -> float: ...
    @overload
    def getYMin() -> double: ...
    def idx2cxcy(self, idx: int, cx: int, cy: int) -> None: ...
    @overload
    def idx2x(self, cx: int) -> float: ...
    @overload
    def idx2x(int) -> double: ...
    @overload
    def idx2y(self, cy: int) -> float: ...
    @overload
    def idx2y(int) -> double: ...
    @overload
    def resize(self, new_x_min: float, new_x_max: float, new_y_min: float, new_y_max: float, defaultValueNewCells: int) -> None: ...
    @overload
    def resize(self, new_x_min: float, new_x_max: float, new_y_min: float, new_y_max: float, defaultValueNewCells: int, additionalMarginMeters: float) -> None: ...
    @overload
    def saveToTextFile(self, fileName: str) -> bool: ...
    @overload
    def saveToTextFile(conststd) -> bool: ...
    @overload
    def setSize(self, x_min: float, x_max: float, y_min: float, y_max: float, resolution: float) -> None: ...
    @overload
    def setSize(self, x_min: float, x_max: float, y_min: float, y_max: float, resolution: float, fill_value: int) -> None: ...
    @overload
    def x2idx(self, x: float) -> int: ...
    @overload
    def x2idx(double) -> int: ...
    def xy2idx(self, x: float, y: float) -> int: ...
    @overload
    def y2idx(self, y: float) -> int: ...
    @overload
    def y2idx(double) -> int: ...

class CDynamicGrid_unsigned_char_t:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float, arg2: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float, arg2: float, arg3: float) -> None: ...
    @overload
    def __init__(self, x_min: float, x_max: float, y_min: float, y_max: float, resolution: float) -> None: ...
    @overload
    def __init__(self, arg0: CDynamicGrid_unsigned_char_t) -> None: ...
    @overload
    def __init__(self, arg0: CDynamicGrid_unsigned_char_t) -> None: ...
    def assign(self) -> CDynamicGrid_unsigned_char_t: ...
    def cell2float(self) -> float: ...
    def cellByIndex(self, cx: int, cy: int) -> int: ...
    def cellByPos(self, x: float, y: float) -> int: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    def fill(self, value: int) -> None: ...
    @overload
    def getResolution(self) -> float: ...
    @overload
    def getResolution() -> double: ...
    @overload
    def getSizeX(self) -> int: ...
    @overload
    def getSizeX() -> size_t: ...
    @overload
    def getSizeY(self) -> int: ...
    @overload
    def getSizeY() -> size_t: ...
    @overload
    def getXMax(self) -> float: ...
    @overload
    def getXMax() -> double: ...
    @overload
    def getXMin(self) -> float: ...
    @overload
    def getXMin() -> double: ...
    @overload
    def getYMax(self) -> float: ...
    @overload
    def getYMax() -> double: ...
    @overload
    def getYMin(self) -> float: ...
    @overload
    def getYMin() -> double: ...
    def idx2cxcy(self, idx: int, cx: int, cy: int) -> None: ...
    @overload
    def idx2x(self, cx: int) -> float: ...
    @overload
    def idx2x(int) -> double: ...
    @overload
    def idx2y(self, cy: int) -> float: ...
    @overload
    def idx2y(int) -> double: ...
    @overload
    def resize(self, new_x_min: float, new_x_max: float, new_y_min: float, new_y_max: float, defaultValueNewCells: int) -> None: ...
    @overload
    def resize(self, new_x_min: float, new_x_max: float, new_y_min: float, new_y_max: float, defaultValueNewCells: int, additionalMarginMeters: float) -> None: ...
    @overload
    def saveToTextFile(self, fileName: str) -> bool: ...
    @overload
    def saveToTextFile(conststd) -> bool: ...
    @overload
    def setSize(self, x_min: float, x_max: float, y_min: float, y_max: float, resolution: float) -> None: ...
    @overload
    def setSize(self, x_min: float, x_max: float, y_min: float, y_max: float, resolution: float, fill_value: int) -> None: ...
    @overload
    def x2idx(self, x: float) -> int: ...
    @overload
    def x2idx(double) -> int: ...
    def xy2idx(self, x: float, y: float) -> int: ...
    @overload
    def y2idx(self, y: float) -> int: ...
    @overload
    def y2idx(double) -> int: ...

class CDynamicGrid_unsigned_short_t:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float, arg2: float) -> None: ...
    @overload
    def __init__(self, arg0: float, arg1: float, arg2: float, arg3: float) -> None: ...
    @overload
    def __init__(self, x_min: float, x_max: float, y_min: float, y_max: float, resolution: float) -> None: ...
    @overload
    def __init__(self, arg0: CDynamicGrid_unsigned_short_t) -> None: ...
    @overload
    def __init__(self, arg0: CDynamicGrid_unsigned_short_t) -> None: ...
    def assign(self) -> CDynamicGrid_unsigned_short_t: ...
    def cell2float(self) -> float: ...
    def cellByIndex(self, cx: int, cy: int) -> int: ...
    def cellByPos(self, x: float, y: float) -> int: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    def fill(self, value: int) -> None: ...
    @overload
    def getResolution(self) -> float: ...
    @overload
    def getResolution() -> double: ...
    @overload
    def getSizeX(self) -> int: ...
    @overload
    def getSizeX() -> size_t: ...
    @overload
    def getSizeY(self) -> int: ...
    @overload
    def getSizeY() -> size_t: ...
    @overload
    def getXMax(self) -> float: ...
    @overload
    def getXMax() -> double: ...
    @overload
    def getXMin(self) -> float: ...
    @overload
    def getXMin() -> double: ...
    @overload
    def getYMax(self) -> float: ...
    @overload
    def getYMax() -> double: ...
    @overload
    def getYMin(self) -> float: ...
    @overload
    def getYMin() -> double: ...
    def idx2cxcy(self, idx: int, cx: int, cy: int) -> None: ...
    @overload
    def idx2x(self, cx: int) -> float: ...
    @overload
    def idx2x(int) -> double: ...
    @overload
    def idx2y(self, cy: int) -> float: ...
    @overload
    def idx2y(int) -> double: ...
    @overload
    def resize(self, new_x_min: float, new_x_max: float, new_y_min: float, new_y_max: float, defaultValueNewCells: int) -> None: ...
    @overload
    def resize(self, new_x_min: float, new_x_max: float, new_y_min: float, new_y_max: float, defaultValueNewCells: int, additionalMarginMeters: float) -> None: ...
    @overload
    def saveToTextFile(self, fileName: str) -> bool: ...
    @overload
    def saveToTextFile(conststd) -> bool: ...
    @overload
    def setSize(self, x_min: float, x_max: float, y_min: float, y_max: float, resolution: float) -> None: ...
    @overload
    def setSize(self, x_min: float, x_max: float, y_min: float, y_max: float, resolution: float, fill_value: int) -> None: ...
    @overload
    def x2idx(self, x: float) -> int: ...
    @overload
    def x2idx(double) -> int: ...
    def xy2idx(self, x: float, y: float) -> int: ...
    @overload
    def y2idx(self, y: float) -> int: ...
    @overload
    def y2idx(double) -> int: ...

class CommentPosition:
    __doc__: ClassVar[str] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    MAX: ClassVar[CommentPosition] = ...
    RIGHT: ClassVar[CommentPosition] = ...
    TOP: ClassVar[CommentPosition] = ...
    __entries: ClassVar[dict] = ...
    def __init__(self, value: int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __ne__(self, other: object) -> bool: ...
    def __setstate__(self, state: int) -> None: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class MT_buffer:
    def __init__(self) -> None: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    @overload
    def size(self) -> int: ...
    @overload
    def size() -> size_t: ...

class YamlEmitOptions:
    emitComments: bool
    emitHeader: bool
    endWithNewLine: bool
    indentSequences: bool
    def __init__(self) -> None: ...

class bimap_long_unsigned_int_t:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: bimap_long_unsigned_int_t) -> None: ...
    def assign(self) -> bimap_long_unsigned_int_t: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    @overload
    def direct(self, k: int, out_v: int) -> bool: ...
    @overload
    def direct(self, k: int) -> int: ...
    @overload
    def empty(self) -> bool: ...
    @overload
    def empty() -> bool: ...
    def erase_by_key(self, k: int) -> None: ...
    def erase_by_value(self, v: int) -> None: ...
    def hasKey(self, k: int) -> bool: ...
    def hasValue(self, v: int) -> bool: ...
    def insert(self, k: int, v: int) -> None: ...
    @overload
    def inverse(self, v: int, out_k: int) -> bool: ...
    @overload
    def inverse(self, v: int) -> int: ...
    @overload
    def size(self) -> int: ...
    @overload
    def size() -> size_t: ...

class circular_buffer_unsigned_char_t:
    @overload
    def __init__(self, size: int) -> None: ...
    @overload
    def __init__(self, arg0: circular_buffer_unsigned_char_t) -> None: ...
    def assign(self) -> circular_buffer_unsigned_char_t: ...
    @overload
    def available(self) -> int: ...
    @overload
    def available() -> size_t: ...
    @overload
    def capacity(self) -> int: ...
    @overload
    def capacity() -> size_t: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    @overload
    def peek(self) -> int: ...
    @overload
    def peek() -> unsignedchar: ...
    @overload
    def peek(self, index: int) -> int: ...
    @overload
    def peek(size_t) -> unsignedchar: ...
    def peek_many(self, out_array: int, count: int) -> None: ...
    @overload
    def pop(self) -> int: ...
    @overload
    def pop() -> unsignedchar: ...
    @overload
    def pop(self, out_val: int) -> None: ...
    def pop_many(self, out_array: int, count: int) -> None: ...
    @overload
    def push(self, d: int) -> None: ...
    @overload
    def push(unsignedchar) -> void: ...
    def push_many(self, array_elements: int, count: int) -> None: ...
    def push_ref(self, d: int) -> None: ...
    @overload
    def size(self) -> int: ...
    @overload
    def size() -> size_t: ...

class map_traits_map_as_vector:
    def __init__(self) -> None: ...

class map_traits_stdmap:
    def __init__(self) -> None: ...

class yaml:
    class mark_t:
        column: int
        input_pos: int
        line: int
        @overload
        def __init__(self, arg0: yaml.mark_t) -> None: ...
        @overload
        def __init__(self) -> None: ...
        def assign(self) -> yaml.mark_t: ...

    class node_t:
        comments: List[Optional[str][2]]
        d: Any
        marks: Any
        printInShortFormat: bool
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, str: str) -> None: ...
        @overload
        def __init__(self, arg0: yaml.node_t) -> None: ...
        @overload
        def asMap(self) -> Dict[yaml.node_t,yaml.node_t]: ...
        @overload
        def asMap() -> Any: ...
        def assign(self) -> yaml.node_t: ...
        @overload
        def comment(self) -> str: ...
        @overload
        def comment(self, pos: CommentPosition) -> str: ...
        @overload
        def hasComment(self) -> bool: ...
        @overload
        def hasComment() -> bool: ...
        @overload
        def hasComment(self, pos: CommentPosition) -> bool: ...
        @overload
        def hasComment(enummrpt) -> bool: ...
        @overload
        def isMap(self) -> bool: ...
        @overload
        def isMap() -> bool: ...
        @overload
        def isNullNode(self) -> bool: ...
        @overload
        def isNullNode() -> bool: ...
        @overload
        def isScalar(self) -> bool: ...
        @overload
        def isScalar() -> bool: ...
        @overload
        def isSequence(self) -> bool: ...
        @overload
        def isSequence() -> bool: ...
        @overload
        def size(self) -> int: ...
        @overload
        def size() -> size_t: ...
        def typeName(self) -> str: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: yaml) -> None: ...
    @overload
    def __init__(self, s) -> None: ...
    def FromFile(self, *args, **kwargs) -> Any: ...
    def FromText(self, *args, **kwargs) -> Any: ...
    def Map(self, *args, **kwargs) -> Any: ...
    def Sequence(self, *args, **kwargs) -> Any: ...
    @overload
    def as(self) -> bool: ...
    @overload
    def as() -> bool: ...
    @overload
    def as(self) -> float: ...
    @overload
    def as() -> double: ...
    @overload
    def as(self) -> float: ...
    @overload
    def as() -> float: ...
    @overload
    def as(self) -> int: ...
    @overload
    def as() -> signedchar: ...
    @overload
    def as(self) -> int: ...
    @overload
    def as() -> unsignedchar: ...
    @overload
    def as(self) -> int: ...
    @overload
    def as() -> short: ...
    @overload
    def as(self) -> int: ...
    @overload
    def as() -> unsignedshort: ...
    @overload
    def as(self) -> int: ...
    @overload
    def as() -> int: ...
    @overload
    def as(self) -> int: ...
    @overload
    def as() -> unsignedint: ...
    @overload
    def as(self) -> int: ...
    @overload
    def as() -> long: ...
    @overload
    def as(self) -> int: ...
    @overload
    def as() -> unsignedlong: ...
    @overload
    def as(self) -> str: ...
    def asMap(self) -> Any: ...
    def asMapRange(self, *args, **kwargs) -> Any: ...
    @overload
    def assign(self, v: int) -> yaml: ...
    @overload
    def assign(self, v: bool) -> yaml: ...
    @overload
    def assign(self, v: float) -> yaml: ...
    @overload
    def assign(self, v: float) -> yaml: ...
    @overload
    def assign(self, v: int) -> yaml: ...
    @overload
    def assign(self, v: int) -> yaml: ...
    @overload
    def assign(self, v: int) -> yaml: ...
    @overload
    def assign(self, v: int) -> yaml: ...
    @overload
    def assign(self, v: int) -> yaml: ...
    @overload
    def assign(self, v: int) -> yaml: ...
    @overload
    def assign(self, v: int) -> yaml: ...
    @overload
    def assign(self, v: int) -> yaml: ...
    @overload
    def assign(self, v: str) -> yaml: ...
    @overload
    def assign(self, v: str) -> yaml: ...
    @overload
    def assign(self, v: yaml) -> yaml: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    @overload
    def comment(self) -> str: ...
    @overload
    def comment(self, pos: CommentPosition) -> str: ...
    @overload
    def comment(self, c: str) -> None: ...
    @overload
    def comment(self, c: str, position: CommentPosition) -> None: ...
    @overload
    def comment(conststd, enummrpt) -> void: ...
    @overload
    def empty(self) -> bool: ...
    @overload
    def empty() -> bool: ...
    @overload
    def getOrDefault(self, key: str, defaultValue: bool) -> bool: ...
    @overload
    def getOrDefault(self, key: str, defaultValue: float) -> float: ...
    @overload
    def getOrDefault(self, key: str, defaultValue: int) -> int: ...
    def has(self, key: str) -> bool: ...
    @overload
    def hasComment(self) -> bool: ...
    @overload
    def hasComment() -> bool: ...
    @overload
    def hasComment(self, pos: CommentPosition) -> bool: ...
    @overload
    def hasComment(enummrpt) -> bool: ...
    @overload
    def isMap(self) -> bool: ...
    @overload
    def isMap() -> bool: ...
    @overload
    def isNullNode(self) -> bool: ...
    @overload
    def isNullNode() -> bool: ...
    @overload
    def isScalar(self) -> bool: ...
    @overload
    def isScalar() -> bool: ...
    @overload
    def isSequence(self) -> bool: ...
    @overload
    def isSequence() -> bool: ...
    @overload
    def keyComment(self, key: str) -> str: ...
    @overload
    def keyComment(self, key: str, pos: CommentPosition) -> str: ...
    @overload
    def keyComment(self, key: str, c: str) -> None: ...
    @overload
    def keyComment(self, key: str, c: str, position: CommentPosition) -> None: ...
    @overload
    def keyHasComment(self, key: str) -> bool: ...
    @overload
    def keyHasComment(conststd) -> bool: ...
    @overload
    def keyHasComment(self, key: str, pos: CommentPosition) -> bool: ...
    @overload
    def keyHasComment(conststd, enummrpt) -> bool: ...
    def keyNode(self, *args, **kwargs) -> Any: ...
    @overload
    def loadFromFile(self, fileName: str) -> None: ...
    @overload
    def loadFromFile(conststd) -> void: ...
    @overload
    def loadFromText(self, yamlTextBlock: str) -> None: ...
    @overload
    def loadFromText(conststd) -> void: ...
    def node(self, *args, **kwargs) -> Any: ...
    @overload
    def printAsYAML(self) -> None: ...
    @overload
    def printAsYAML() -> void: ...
    @overload
    def push_back(self, v: float) -> None: ...
    @overload
    def push_back(double) -> void: ...
    @overload
    def push_back(self, v: str) -> None: ...
    @overload
    def push_back(conststd) -> void: ...
    @overload
    def push_back(self, v: int) -> None: ...
    @overload
    def push_back(uint64_t) -> void: ...
    @overload
    def push_back(self, v: bool) -> None: ...
    @overload
    def push_back(bool) -> void: ...
    @overload
    def push_back(self, v: yaml) -> None: ...
    @overload
    def push_back(constclassmrpt) -> void: ...
    @overload
    def size(self) -> int: ...
    @overload
    def size() -> size_t: ...
    def __call__(self, index: int) -> yaml: ...
    @overload
    def __getitem__(self, key: str) -> yaml: ...
    @overload
    def __getitem__(self, key: str) -> yaml: ...



from typing import Any

from typing import overload
import mrpt.pymrpt.mrpt
import mrpt.pymrpt.mrpt.config
import mrpt.pymrpt.mrpt.math
import mrpt.pymrpt.mrpt.poses
import mrpt.pymrpt.mrpt.rtti
import mrpt.pymrpt.mrpt.serialization

class CKinematicChain(mrpt.pymrpt.mrpt.serialization.CSerializable):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: CKinematicChain) -> None: ...
    @overload
    def __init__(self, arg0: CKinematicChain) -> None: ...
    def CreateObject(self, *args, **kwargs) -> Any: ...
    def GetRuntimeClass(self) -> mrpt.pymrpt.mrpt.rtti.TRuntimeClassId: ...
    def GetRuntimeClassIdStatic(self, *args, **kwargs) -> Any: ...
    def addLink(self, theta: float, d: float, a: float, alpha: float, is_prismatic: bool) -> None: ...
    def assign(self) -> CKinematicChain: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    def clone(self) -> mrpt.pymrpt.mrpt.rtti.CObject: ...
    def getLink(self, idx: int) -> TKinematicLink: ...
    def getLinkRef(self, idx: int) -> TKinematicLink: ...
    def getOriginPose(self) -> mrpt.pymrpt.mrpt.poses.CPose3D: ...
    @overload
    def removeLink(self, idx: int) -> None: ...
    @overload
    def removeLink(size_t) -> void: ...
    @overload
    def setOriginPose(self, new_pose: mrpt.pymrpt.mrpt.poses.CPose3D) -> None: ...
    @overload
    def setOriginPose(constclassmrpt) -> void: ...
    @overload
    def size(self) -> int: ...
    @overload
    def size() -> size_t: ...

class CVehicleSimulVirtualBase:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: CVehicleSimulVirtualBase) -> None: ...
    def assign(self) -> CVehicleSimulVirtualBase: ...
    def getCurrentGTPose(self) -> mrpt.pymrpt.mrpt.math.TPose2D: ...
    def getCurrentGTVel(self, *args, **kwargs) -> Any: ...
    def getCurrentGTVelLocal(self, *args, **kwargs) -> Any: ...
    def getCurrentOdometricPose(self) -> mrpt.pymrpt.mrpt.math.TPose2D: ...
    def getCurrentOdometricVel(self, *args, **kwargs) -> Any: ...
    def getCurrentOdometricVelLocal(self, *args, **kwargs) -> Any: ...
    @overload
    def getTime(self) -> float: ...
    @overload
    def getTime() -> double: ...
    def getVelCmdType(self) -> CVehicleVelCmd: ...
    @overload
    def resetStatus(self) -> None: ...
    @overload
    def resetStatus() -> void: ...
    @overload
    def resetTime(self) -> None: ...
    @overload
    def resetTime() -> void: ...
    @overload
    def sendVelCmd(self, cmd_vel: CVehicleVelCmd) -> None: ...
    @overload
    def sendVelCmd(constclassmrpt) -> void: ...
    @overload
    def setCurrentGTPose(self, pose: mrpt.pymrpt.mrpt.math.TPose2D) -> None: ...
    @overload
    def setCurrentGTPose(conststructmrpt) -> void: ...
    @overload
    def setOdometryErrors(self, enabled: bool) -> None: ...
    @overload
    def setOdometryErrors(self, enabled: bool, Ax_err_bias: float) -> None: ...
    @overload
    def setOdometryErrors(self, enabled: bool, Ax_err_bias: float, Ax_err_std: float) -> None: ...
    @overload
    def setOdometryErrors(self, enabled: bool, Ax_err_bias: float, Ax_err_std: float, Ay_err_bias: float) -> None: ...
    @overload
    def setOdometryErrors(self, enabled: bool, Ax_err_bias: float, Ax_err_std: float, Ay_err_bias: float, Ay_err_std: float) -> None: ...
    @overload
    def setOdometryErrors(self, enabled: bool, Ax_err_bias: float, Ax_err_std: float, Ay_err_bias: float, Ay_err_std: float, Aphi_err_bias: float) -> None: ...
    @overload
    def setOdometryErrors(self, enabled: bool, Ax_err_bias: float, Ax_err_std: float, Ay_err_bias: float, Ay_err_std: float, Aphi_err_bias: float, Aphi_err_std: float) -> None: ...
    def simulateOneTimeStep(self, dt: float) -> None: ...

class CVehicleSimul_DiffDriven(CVehicleSimulVirtualBase):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: CVehicleSimul_DiffDriven) -> None: ...
    @overload
    def __init__(self, arg0: CVehicleSimul_DiffDriven) -> None: ...
    def assign(self) -> CVehicleSimul_DiffDriven: ...
    @overload
    def getV(self) -> float: ...
    @overload
    def getV() -> double: ...
    def getVelCmdType(self) -> CVehicleVelCmd: ...
    @overload
    def getW(self) -> float: ...
    @overload
    def getW() -> double: ...
    def movementCommand(self, lin_vel: float, ang_vel: float) -> None: ...
    @overload
    def sendVelCmd(self, cmd_vel: CVehicleVelCmd) -> None: ...
    @overload
    def sendVelCmd(constclassmrpt) -> void: ...
    @overload
    def setDelayModelParams(self) -> None: ...
    @overload
    def setDelayModelParams(self, TAU_delay_sec: float) -> None: ...
    @overload
    def setDelayModelParams(self, TAU_delay_sec: float, CMD_delay_sec: float) -> None: ...
    @overload
    def setV(self, v: float) -> None: ...
    @overload
    def setV(double) -> void: ...
    @overload
    def setW(self, w: float) -> None: ...
    @overload
    def setW(double) -> void: ...

class CVehicleSimul_Holo(CVehicleSimulVirtualBase):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: CVehicleSimul_Holo) -> None: ...
    @overload
    def __init__(self, arg0: CVehicleSimul_Holo) -> None: ...
    def assign(self) -> CVehicleSimul_Holo: ...
    def getVelCmdType(self) -> CVehicleVelCmd: ...
    @overload
    def sendVelCmd(self, cmd_vel: CVehicleVelCmd) -> None: ...
    @overload
    def sendVelCmd(constclassmrpt) -> void: ...
    def sendVelRampCmd(self, vel: float, dir: float, ramp_time: float, rot_speed: float) -> None: ...

class CVehicleVelCmd(mrpt.pymrpt.mrpt.serialization.CSerializable, mrpt.pymrpt.mrpt.Stringifyable):
    class TVelCmdParams:
        robotMax_V_mps: float
        robotMax_W_radps: float
        robotMinCurvRadius: float
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, arg0: CVehicleVelCmd.TVelCmdParams) -> None: ...
        def assign(self) -> CVehicleVelCmd.TVelCmdParams: ...
        @overload
        def loadConfigFile(self, cfg: mrpt.pymrpt.mrpt.config.CConfigFileBase, section: str) -> None: ...
        @overload
        def loadConfigFile(constclassmrpt, conststd) -> void: ...
        @overload
        def saveToConfigFile(self, c: mrpt.pymrpt.mrpt.config.CConfigFileBase, s: str) -> None: ...
        @overload
        def saveToConfigFile(classmrpt, conststd) -> void: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: CVehicleVelCmd) -> None: ...
    def GetRuntimeClass(self) -> mrpt.pymrpt.mrpt.rtti.TRuntimeClassId: ...
    def GetRuntimeClassIdStatic(self, *args, **kwargs) -> Any: ...
    def asString(self) -> str: ...
    def assign(self, other: CVehicleVelCmd) -> CVehicleVelCmd: ...
    @overload
    def cmdVel_limits(self, prev_vel_cmd: CVehicleVelCmd, beta: float, params) -> float: ...
    @overload
    def cmdVel_limits(constclassmrpt, constdouble, conststructmrpt) -> double: ...
    @overload
    def cmdVel_scale(self, vel_scale: float) -> None: ...
    @overload
    def cmdVel_scale(double) -> void: ...
    def getVelCmdDescription(self, index: int) -> str: ...
    @overload
    def getVelCmdElement(self, index: int) -> float: ...
    @overload
    def getVelCmdElement(constint) -> double: ...
    @overload
    def getVelCmdLength(self) -> int: ...
    @overload
    def getVelCmdLength() -> size_t: ...
    @overload
    def isStopCmd(self) -> bool: ...
    @overload
    def isStopCmd() -> bool: ...
    @overload
    def setToStop(self) -> None: ...
    @overload
    def setToStop() -> void: ...
    @overload
    def setVelCmdElement(self, index: int, val: float) -> None: ...
    @overload
    def setVelCmdElement(constint, constdouble) -> void: ...

class CVehicleVelCmd_DiffDriven(CVehicleVelCmd):
    ang_vel: float
    lin_vel: float
    @overload
    def __init__(self, arg0: CVehicleVelCmd_DiffDriven) -> None: ...
    @overload
    def __init__(self, arg0: CVehicleVelCmd_DiffDriven) -> None: ...
    @overload
    def __init__(self) -> None: ...
    def CreateObject(self, *args, **kwargs) -> Any: ...
    def GetRuntimeClass(self) -> mrpt.pymrpt.mrpt.rtti.TRuntimeClassId: ...
    def GetRuntimeClassIdStatic(self, *args, **kwargs) -> Any: ...
    def assign(self) -> CVehicleVelCmd_DiffDriven: ...
    def clone(self) -> mrpt.pymrpt.mrpt.rtti.CObject: ...
    @overload
    def cmdVel_limits(self, prev_vel_cmd: CVehicleVelCmd, beta: float, params: CVehicleVelCmd.TVelCmdParams) -> float: ...
    @overload
    def cmdVel_limits(constclassmrpt, constdouble, conststructmrpt) -> double: ...
    @overload
    def cmdVel_scale(self, vel_scale: float) -> None: ...
    @overload
    def cmdVel_scale(double) -> void: ...
    def getVelCmdDescription(self, index: int) -> str: ...
    @overload
    def getVelCmdElement(self, index: int) -> float: ...
    @overload
    def getVelCmdElement(constint) -> double: ...
    @overload
    def getVelCmdLength(self) -> int: ...
    @overload
    def getVelCmdLength() -> size_t: ...
    @overload
    def isStopCmd(self) -> bool: ...
    @overload
    def isStopCmd() -> bool: ...
    @overload
    def setToStop(self) -> None: ...
    @overload
    def setToStop() -> void: ...
    @overload
    def setVelCmdElement(self, index: int, val: float) -> None: ...
    @overload
    def setVelCmdElement(constint, constdouble) -> void: ...

class CVehicleVelCmd_Holo(CVehicleVelCmd):
    dir_local: float
    ramp_time: float
    rot_speed: float
    vel: float
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, vel: float, dir_local: float, ramp_time: float, rot_speed: float) -> None: ...
    @overload
    def __init__(self, arg0: CVehicleVelCmd_Holo) -> None: ...
    @overload
    def __init__(self, arg0: CVehicleVelCmd_Holo) -> None: ...
    def CreateObject(self, *args, **kwargs) -> Any: ...
    def GetRuntimeClass(self) -> mrpt.pymrpt.mrpt.rtti.TRuntimeClassId: ...
    def GetRuntimeClassIdStatic(self, *args, **kwargs) -> Any: ...
    def assign(self) -> CVehicleVelCmd_Holo: ...
    def clone(self) -> mrpt.pymrpt.mrpt.rtti.CObject: ...
    @overload
    def cmdVel_limits(self, prev_vel_cmd: CVehicleVelCmd, beta: float, params: CVehicleVelCmd.TVelCmdParams) -> float: ...
    @overload
    def cmdVel_limits(constclassmrpt, constdouble, conststructmrpt) -> double: ...
    @overload
    def cmdVel_scale(self, vel_scale: float) -> None: ...
    @overload
    def cmdVel_scale(double) -> void: ...
    def getVelCmdDescription(self, index: int) -> str: ...
    @overload
    def getVelCmdElement(self, index: int) -> float: ...
    @overload
    def getVelCmdElement(constint) -> double: ...
    @overload
    def getVelCmdLength(self) -> int: ...
    @overload
    def getVelCmdLength() -> size_t: ...
    @overload
    def isStopCmd(self) -> bool: ...
    @overload
    def isStopCmd() -> bool: ...
    @overload
    def setToStop(self) -> None: ...
    @overload
    def setToStop() -> void: ...
    @overload
    def setVelCmdElement(self, index: int, val: float) -> None: ...
    @overload
    def setVelCmdElement(constint, constdouble) -> void: ...

class TKinematicLink:
    a: float
    alpha: float
    d: float
    is_prismatic: bool
    theta: float
    @overload
    def __init__(self, _theta: float, _d: float, _a: float, _alpha: float, _is_prismatic: bool) -> None: ...
    @overload
    def __init__(self) -> None: ...



from typing import Any

from typing import overload
import mrpt.pymrpt

class Color:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, intensity: float, alpha: float) -> None: ...
    @overload
    def __init__(self, intensity: int, alpha: int) -> None: ...
    @overload
    def __init__(self, r: float, g: float, b: float, a: float) -> None: ...
    @overload
    def __init__(self, r: int, g: int, b: int, a: int) -> None: ...
    @overload
    def __init__(self, arg0: Color) -> None: ...
    def assign(self) -> Color: ...
    def b(self) -> float: ...
    def contrastingColor(self) -> Color: ...
    def g(self) -> float: ...
    def r(self) -> float: ...

class GLCanvas:
    @overload
    def __init__(self, arg0: GLCanvas) -> None: ...
    @overload
    def __init__(self, arg0: GLCanvas) -> None: ...
    def backgroundColor(self) -> Color: ...
    def draw(self, ctx: mrpt.pymrpt.NVGcontext) -> None: ...
    def drawBorder(self) -> bool: ...
    @overload
    def drawGL(self) -> None: ...
    @overload
    def drawGL() -> void: ...
    @overload
    def setBackgroundColor(self, backgroundColor: Color) -> None: ...
    @overload
    def setBackgroundColor(constclassnanogui) -> void: ...
    @overload
    def setDrawBorder(self, bDrawBorder: bool) -> None: ...
    @overload
    def setDrawBorder(constbool) -> void: ...

class Screen:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: Screen) -> None: ...
    @overload
    def __init__(self, arg0: Screen) -> None: ...
    def background(self) -> Color: ...
    def caption(self) -> str: ...
    @overload
    def centerWindow(self, window) -> None: ...
    @overload
    def centerWindow(classnanogui) -> void: ...
    @overload
    def charCallbackEvent(self, codepoint: int) -> bool: ...
    @overload
    def charCallbackEvent(unsignedint) -> bool: ...
    def cursorPosCallbackEvent(self, x: float, y: float) -> bool: ...
    @overload
    def disposeWindow(self, window) -> None: ...
    @overload
    def disposeWindow(classnanogui) -> void: ...
    @overload
    def drawAll(self) -> None: ...
    @overload
    def drawAll() -> void: ...
    @overload
    def drawContents(self) -> None: ...
    @overload
    def drawContents() -> void: ...
    @overload
    def drawWidgets(self) -> None: ...
    @overload
    def drawWidgets() -> void: ...
    @overload
    def dropEvent(self) -> bool: ...
    @overload
    def dropEvent(constclassstd) -> bool: ...
    def glfwWindow(self) -> mrpt.pymrpt.GLFWwindow: ...
    def initialize(self, window: mrpt.pymrpt.GLFWwindow, shutdownGLFWOnDestruct: bool) -> None: ...
    def keyCallbackEvent(self, key: int, scancode: int, action: int, mods: int) -> bool: ...
    @overload
    def keyboardCharacterEvent(self, codepoint: int) -> bool: ...
    @overload
    def keyboardCharacterEvent(unsignedint) -> bool: ...
    def keyboardEvent(self, key: int, scancode: int, action: int, modifiers: int) -> bool: ...
    def mouseButtonCallbackEvent(self, button: int, action: int, modifiers: int) -> bool: ...
    @overload
    def mouseModifiers(self) -> int: ...
    @overload
    def mouseModifiers() -> int: ...
    @overload
    def mouseState(self) -> int: ...
    @overload
    def mouseState() -> int: ...
    @overload
    def moveWindowToFront(self, window) -> None: ...
    @overload
    def moveWindowToFront(classnanogui) -> void: ...
    def nvgContext(self) -> mrpt.pymrpt.NVGcontext: ...
    @overload
    def onIdleLoopTasks(self) -> None: ...
    @overload
    def onIdleLoopTasks() -> void: ...
    @overload
    def performLayout(self, ctx: mrpt.pymrpt.NVGcontext) -> None: ...
    @overload
    def performLayout(self) -> None: ...
    @overload
    def performLayout() -> void: ...
    @overload
    def pixelRatio(self) -> float: ...
    @overload
    def pixelRatio() -> float: ...
    def resizeCallback(self, *args, **kwargs) -> Any: ...
    def resizeCallbackEvent(self, width: int, height: int) -> bool: ...
    def scrollCallbackEvent(self, x: float, y: float) -> bool: ...
    @overload
    def setBackground(self, background: Color) -> None: ...
    @overload
    def setBackground(constclassnanogui) -> void: ...
    @overload
    def setCaption(self, caption: str) -> None: ...
    @overload
    def setCaption(conststd) -> void: ...
    @overload
    def setResizeCallback(self, callback) -> None: ...
    @overload
    def setResizeCallback(constclassstd) -> void: ...
    @overload
    def setShutdownGLFWOnDestruct(self, v: bool) -> None: ...
    @overload
    def setShutdownGLFWOnDestruct(bool) -> void: ...
    @overload
    def setVisible(self, visible: bool) -> None: ...
    @overload
    def setVisible(bool) -> void: ...
    @overload
    def shutdownGLFWOnDestruct(self) -> bool: ...
    @overload
    def shutdownGLFWOnDestruct() -> bool: ...

class Window:
    @overload
    def __init__(self, arg0: Window) -> None: ...
    @overload
    def __init__(self, arg0: Window) -> None: ...
    @overload
    def center(self) -> None: ...
    @overload
    def center() -> void: ...
    @overload
    def dispose(self) -> None: ...
    @overload
    def dispose() -> void: ...
    def draw(self, ctx: mrpt.pymrpt.NVGcontext) -> None: ...
    @overload
    def modal(self) -> bool: ...
    @overload
    def modal() -> bool: ...
    def performLayout(self, ctx: mrpt.pymrpt.NVGcontext) -> None: ...
    @overload
    def setModal(self, modal: bool) -> None: ...
    @overload
    def setModal(bool) -> void: ...
    @overload
    def setTitle(self, title: str) -> None: ...
    @overload
    def setTitle(conststd) -> void: ...
    def title(self) -> str: ...



from . import comms, io, obs, opengl, poses, rtti, system, typemeta
from . import apps, bayes, config, containers, cpu, expr, global_settings
from . import graphs, gui, hwdrivers, img, kinematics, maps, math, nav
from . import random, serialization, slam, tfest, topography, vision


from typing import Any, ClassVar, List

from typing import overload

class Clock:
    class Source:
        __doc__: ClassVar[str] = ...  # read-only
        __members__: ClassVar[dict] = ...  # read-only
        Monotonic: ClassVar[Clock.Source] = ...
        Realtime: ClassVar[Clock.Source] = ...
        Simulated: ClassVar[Clock.Source] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __and__(self, other: object) -> object: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> object: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: object) -> object: ...
        def __rand__(self, other: object) -> object: ...
        def __ror__(self, other: object) -> object: ...
        def __rxor__(self, other: object) -> object: ...
        def __setstate__(self, state: int) -> None: ...
        def __xor__(self, other: object) -> object: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...
    Monotonic: ClassVar[Clock.Source] = ...
    Realtime: ClassVar[Clock.Source] = ...
    Simulated: ClassVar[Clock.Source] = ...
    def __init__(self) -> None: ...
    def fromDouble(self, *args, **kwargs) -> Any: ...
    def getActiveClock(self, *args, **kwargs) -> Any: ...
    def getMonotonicToRealtimeOffset(self, *args, **kwargs) -> Any: ...
    def now(self, *args, **kwargs) -> Any: ...
    def nowDouble(self, *args, **kwargs) -> Any: ...
    def resetMonotonicToRealTimeEpoch(self, *args, **kwargs) -> Any: ...
    def setActiveClock(self, *args, **kwargs) -> Any: ...
    def setSimulatedTime(self, *args, **kwargs) -> Any: ...
    def toDouble(self, *args, **kwargs) -> Any: ...

class Stringifyable:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: Stringifyable) -> None: ...
    def asString(self) -> str: ...
    def assign(self) -> Stringifyable: ...

class TCallStackBackTrace:
    backtrace_levels: List[TCallStackEntry]
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: TCallStackBackTrace) -> None: ...
    def asString(self) -> str: ...
    def assign(self) -> TCallStackBackTrace: ...

class TCallStackEntry:
    sourceFileFullPath: str
    sourceFileName: str
    sourceFileNumber: int
    symbolName: str
    symbolNameOriginal: str
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: TCallStackEntry) -> None: ...
    def assign(self) -> TCallStackEntry: ...

class WorkerThreadsPool:
    class queue_policy_t:
        __doc__: ClassVar[str] = ...  # read-only
        __members__: ClassVar[dict] = ...  # read-only
        POLICY_DROP_OLD: ClassVar[WorkerThreadsPool.queue_policy_t] = ...
        POLICY_FIFO: ClassVar[WorkerThreadsPool.queue_policy_t] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __and__(self, other: object) -> object: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> object: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: object) -> object: ...
        def __rand__(self, other: object) -> object: ...
        def __ror__(self, other: object) -> object: ...
        def __rxor__(self, other: object) -> object: ...
        def __setstate__(self, state: int) -> None: ...
        def __xor__(self, other: object) -> object: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...
    POLICY_DROP_OLD: ClassVar[WorkerThreadsPool.queue_policy_t] = ...
    POLICY_FIFO: ClassVar[WorkerThreadsPool.queue_policy_t] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, num_threads: int) -> None: ...
    @overload
    def __init__(self, num_threads: int, p) -> None: ...
    @overload
    def __init__(self, num_threads: int, p, threadsName: str) -> None: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    @overload
    def name(self, name: str) -> None: ...
    @overload
    def name(conststd) -> void: ...
    @overload
    def name(self) -> str: ...
    def pendingTasks(self) -> int: ...
    @overload
    def resize(self, num_threads: int) -> None: ...
    @overload
    def resize(std) -> void: ...
    def size(self) -> int: ...

class ignored_copy_ptr_mrpt_maps_COctoMapBase_octomap_ColorOcTree_octomap_ColorOcTreeNode_t:
    __hash__: ClassVar[None] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: ignored_copy_ptr_mrpt_maps_COctoMapBase_octomap_ColorOcTree_octomap_ColorOcTreeNode_t) -> None: ...
    @overload
    def __init__(self, p, octomap) -> None: ...
    def arrow(self, *args, **kwargs) -> Any: ...
    @overload
    def assign(self, p, octomap) -> ignored_copy_ptr_mrpt_maps_COctoMapBase_octomap_ColorOcTree_octomap_ColorOcTreeNode_t: ...
    @overload
    def assign(self) -> ignored_copy_ptr_mrpt_maps_COctoMapBase_octomap_ColorOcTree_octomap_ColorOcTreeNode_t: ...
    def get(self, *args, **kwargs) -> Any: ...
    @overload
    def set(self, p, octomap) -> None: ...
    @overload
    def set(constclassmrpt, classoctomap) -> void: ...
    @overload
    def __eq__(self, o, octomap) -> bool: ...
    @overload
    def __eq__(self, o: ignored_copy_ptr_mrpt_maps_COctoMapBase_octomap_ColorOcTree_octomap_ColorOcTreeNode_t) -> bool: ...
    @overload
    def __ne__(self, o, octomap) -> bool: ...
    @overload
    def __ne__(self, o: ignored_copy_ptr_mrpt_maps_COctoMapBase_octomap_ColorOcTree_octomap_ColorOcTreeNode_t) -> bool: ...

class ignored_copy_ptr_mrpt_maps_COctoMapBase_octomap_OcTree_octomap_OcTreeNode_t:
    __hash__: ClassVar[None] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: ignored_copy_ptr_mrpt_maps_COctoMapBase_octomap_OcTree_octomap_OcTreeNode_t) -> None: ...
    @overload
    def __init__(self, p, octomap) -> None: ...
    def arrow(self, *args, **kwargs) -> Any: ...
    @overload
    def assign(self, p, octomap) -> ignored_copy_ptr_mrpt_maps_COctoMapBase_octomap_OcTree_octomap_OcTreeNode_t: ...
    @overload
    def assign(self) -> ignored_copy_ptr_mrpt_maps_COctoMapBase_octomap_OcTree_octomap_OcTreeNode_t: ...
    def get(self, *args, **kwargs) -> Any: ...
    @overload
    def set(self, p, octomap) -> None: ...
    @overload
    def set(constclassmrpt, classoctomap) -> void: ...
    @overload
    def __eq__(self, o, octomap) -> bool: ...
    @overload
    def __eq__(self, o: ignored_copy_ptr_mrpt_maps_COctoMapBase_octomap_OcTree_octomap_OcTreeNode_t) -> bool: ...
    @overload
    def __ne__(self, o, octomap) -> bool: ...
    @overload
    def __ne__(self, o: ignored_copy_ptr_mrpt_maps_COctoMapBase_octomap_OcTree_octomap_OcTreeNode_t) -> bool: ...

class int_select_by_bytecount_1U_t:
    def __init__(self) -> None: ...

class int_select_by_bytecount_2U_t:
    def __init__(self) -> None: ...

class int_select_by_bytecount_3U_t:
    def __init__(self) -> None: ...

class int_select_by_bytecount_4U_t:
    def __init__(self) -> None: ...

class int_select_by_bytecount_8U_t:
    def __init__(self) -> None: ...

class non_copiable_ptr_basic_void_t:
    __hash__: ClassVar[None] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: non_copiable_ptr_basic_void_t) -> None: ...
    @overload
    def __init__(self, p: capsule) -> None: ...
    def arrow(self) -> capsule: ...
    @overload
    def assign(self, p: capsule) -> non_copiable_ptr_basic_void_t: ...
    @overload
    def assign(self) -> non_copiable_ptr_basic_void_t: ...
    def get(self) -> capsule: ...
    def set(self, p: capsule) -> None: ...
    @overload
    def __eq__(self, o: capsule) -> bool: ...
    @overload
    def __eq__(self, o: non_copiable_ptr_basic_void_t) -> bool: ...
    @overload
    def __ne__(self, o: capsule) -> bool: ...
    @overload
    def __ne__(self, o: non_copiable_ptr_basic_void_t) -> bool: ...

class ptr_cast_mrpt_serialization_CSerializable_t:
    def __init__(self) -> None: ...
    def from(self, *args, **kwargs) -> Any: ...

class safe_ptr_basic_mrpt_opengl_Scene_t:
    __hash__: ClassVar[None] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: safe_ptr_basic_mrpt_opengl_Scene_t) -> None: ...
    @overload
    def __init__(self, p) -> None: ...
    def arrow(self, *args, **kwargs) -> Any: ...
    @overload
    def assign(self, p) -> safe_ptr_basic_mrpt_opengl_Scene_t: ...
    @overload
    def assign(self, o: safe_ptr_basic_mrpt_opengl_Scene_t) -> safe_ptr_basic_mrpt_opengl_Scene_t: ...
    def get(self, *args, **kwargs) -> Any: ...
    @overload
    def __eq__(self, o) -> bool: ...
    @overload
    def __eq__(self, o: safe_ptr_basic_mrpt_opengl_Scene_t) -> bool: ...
    @overload
    def __ne__(self, o) -> bool: ...
    @overload
    def __ne__(self, o: safe_ptr_basic_mrpt_opengl_Scene_t) -> bool: ...

class safe_ptr_basic_mrpt_rtti_TRuntimeClassId_t:
    __hash__: ClassVar[None] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: safe_ptr_basic_mrpt_rtti_TRuntimeClassId_t) -> None: ...
    @overload
    def __init__(self, p) -> None: ...
    def arrow(self, *args, **kwargs) -> Any: ...
    @overload
    def assign(self, p) -> safe_ptr_basic_mrpt_rtti_TRuntimeClassId_t: ...
    @overload
    def assign(self, o: safe_ptr_basic_mrpt_rtti_TRuntimeClassId_t) -> safe_ptr_basic_mrpt_rtti_TRuntimeClassId_t: ...
    def get(self, *args, **kwargs) -> Any: ...
    @overload
    def __eq__(self, o) -> bool: ...
    @overload
    def __eq__(self, o: safe_ptr_basic_mrpt_rtti_TRuntimeClassId_t) -> bool: ...
    @overload
    def __ne__(self, o) -> bool: ...
    @overload
    def __ne__(self, o: safe_ptr_basic_mrpt_rtti_TRuntimeClassId_t) -> bool: ...

class safe_ptr_mrpt_opengl_Scene_t(safe_ptr_basic_mrpt_opengl_Scene_t):
    __hash__: ClassVar[None] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: safe_ptr_mrpt_opengl_Scene_t) -> None: ...
    @overload
    def __init__(self, p) -> None: ...
    def arrow(self, *args, **kwargs) -> Any: ...
    @overload
    def assign(self, o: safe_ptr_mrpt_opengl_Scene_t) -> safe_ptr_mrpt_opengl_Scene_t: ...
    @overload
    def assign(self, p) -> safe_ptr_mrpt_opengl_Scene_t: ...
    @overload
    def assign(self, p) -> safe_ptr_basic_mrpt_opengl_Scene_t: ...
    @overload
    def assign(self, o: safe_ptr_basic_mrpt_opengl_Scene_t) -> safe_ptr_basic_mrpt_opengl_Scene_t: ...
    def dereference(self, *args, **kwargs) -> Any: ...
    def get(self, *args, **kwargs) -> Any: ...
    @overload
    def __eq__(self, o) -> bool: ...
    @overload
    def __eq__(self, o: safe_ptr_basic_mrpt_opengl_Scene_t) -> bool: ...
    def __getitem__(self, index) -> Any: ...
    @overload
    def __ne__(self, o) -> bool: ...
    @overload
    def __ne__(self, o: safe_ptr_basic_mrpt_opengl_Scene_t) -> bool: ...

class safe_ptr_mrpt_rtti_TRuntimeClassId_t(safe_ptr_basic_mrpt_rtti_TRuntimeClassId_t):
    __hash__: ClassVar[None] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: safe_ptr_mrpt_rtti_TRuntimeClassId_t) -> None: ...
    @overload
    def __init__(self, p) -> None: ...
    def arrow(self, *args, **kwargs) -> Any: ...
    @overload
    def assign(self, o: safe_ptr_mrpt_rtti_TRuntimeClassId_t) -> safe_ptr_mrpt_rtti_TRuntimeClassId_t: ...
    @overload
    def assign(self, p) -> safe_ptr_mrpt_rtti_TRuntimeClassId_t: ...
    @overload
    def assign(self, p) -> safe_ptr_basic_mrpt_rtti_TRuntimeClassId_t: ...
    @overload
    def assign(self, o: safe_ptr_basic_mrpt_rtti_TRuntimeClassId_t) -> safe_ptr_basic_mrpt_rtti_TRuntimeClassId_t: ...
    def dereference(self, *args, **kwargs) -> Any: ...
    def get(self, *args, **kwargs) -> Any: ...
    @overload
    def __eq__(self, o) -> bool: ...
    @overload
    def __eq__(self, o: safe_ptr_basic_mrpt_rtti_TRuntimeClassId_t) -> bool: ...
    def __getitem__(self, index) -> Any: ...
    @overload
    def __ne__(self, o) -> bool: ...
    @overload
    def __ne__(self, o: safe_ptr_basic_mrpt_rtti_TRuntimeClassId_t) -> bool: ...

class uint_select_by_bytecount_1U_t:
    def __init__(self) -> None: ...

class uint_select_by_bytecount_2U_t:
    def __init__(self) -> None: ...

class uint_select_by_bytecount_3U_t:
    def __init__(self) -> None: ...

class uint_select_by_bytecount_4U_t:
    def __init__(self) -> None: ...

class uint_select_by_bytecount_8U_t:
    def __init__(self) -> None: ...

@overload
def DEG2RAD(x: float) -> float: ...
@overload
def DEG2RAD(constdouble) -> double: ...
@overload
def DEG2RAD(x: float) -> float: ...
@overload
def DEG2RAD(constfloat) -> float: ...
@overload
def DEG2RAD(x: int) -> float: ...
@overload
def DEG2RAD(constint) -> double: ...
@overload
def DEG2RAD(x: float) -> float: ...
@overload
def DEG2RAD(constlongdouble) -> longdouble: ...
@overload
def RAD2DEG(x: float) -> float: ...
@overload
def RAD2DEG(constdouble) -> double: ...
@overload
def RAD2DEG(x: float) -> float: ...
@overload
def RAD2DEG(constfloat) -> float: ...
@overload
def RAD2DEG(x: float) -> float: ...
@overload
def RAD2DEG(constlongdouble) -> longdouble: ...
def aligned_calloc(bytes: int, alignment: int) -> capsule: ...
def aligned_free(ptr: capsule) -> None: ...
def aligned_malloc(size: int, alignment: int) -> capsule: ...
@overload
def callStackBackTrace(out_bt: TCallStackBackTrace) -> None: ...
@overload
def callStackBackTrace(out_bt: TCallStackBackTrace, framesToSkip: int) -> None: ...
@overload
def callStackBackTrace(out_bt: TCallStackBackTrace, framesToSkip: int, framesToCapture: int) -> None: ...
@overload
def callStackBackTrace() -> TCallStackBackTrace: ...
@overload
def callStackBackTrace(framesToSkip: int) -> TCallStackBackTrace: ...
@overload
def callStackBackTrace(framesToSkip: int, framesToCapture: int) -> TCallStackBackTrace: ...
@overload
def d2f(d: float) -> float: ...
@overload
def d2f(constdouble) -> float: ...
@overload
def f2u8(f: float) -> int: ...
@overload
def f2u8(constfloat) -> uint8_t: ...
def hypot_fast(x: float, y: float) -> float: ...
@overload
def keep_max(var: float, test_val: float) -> None: ...
@overload
def keep_max(var: float, test_val: float) -> None: ...
@overload
def keep_max(var: float, test_val: float) -> None: ...
@overload
def keep_min(var: float, test_val: float) -> None: ...
@overload
def keep_min(var: float, test_val: float) -> None: ...
@overload
def keep_min(var: float, test_val: float) -> None: ...
@overload
def round(value: float) -> int: ...
@overload
def round(constfloat) -> int: ...
@overload
def round(value: float) -> int: ...
@overload
def round(constdouble) -> int: ...
@overload
def sign(x: float) -> int: ...
@overload
def sign(double) -> int: ...
@overload
def signWithZero(x: float) -> int: ...
@overload
def signWithZero(double) -> int: ...
@overload
def square(x: float) -> float: ...
@overload
def square(constdouble) -> double: ...
@overload
def square(x: float) -> float: ...
@overload
def square(constfloat) -> float: ...
@overload
def toNativeEndianness(v_in: int) -> int: ...
@overload
def toNativeEndianness(v_in: int) -> int: ...
@overload
def to_string(v: float) -> str: ...
@overload
def to_string(v: int) -> str: ...
@overload
def to_string(v: int) -> str: ...
@overload
def to_string(v: int) -> str: ...
@overload
def to_string(v: float) -> str: ...
@overload
def to_string(v: str) -> str: ...
@overload
def to_string(v: bool) -> str: ...
@overload
def to_string(s: str) -> str: ...
@overload
def u8tof(v: int) -> float: ...
@overload
def u8tof(constunsignedchar) -> float: ...



from typing import Dict

from typing import overload

class CRuntimeCompiledExpression:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: CRuntimeCompiledExpression) -> None: ...
    def assign(self) -> CRuntimeCompiledExpression: ...
    @overload
    def compile(self, expression: str) -> None: ...
    @overload
    def compile(self, expression: str, variables: Dict[str,float]) -> None: ...
    @overload
    def compile(self, expression: str, variables: Dict[str,float], expr_name_for_error_reporting: str) -> None: ...
    @overload
    def eval(self) -> float: ...
    @overload
    def eval() -> double: ...
    def get_original_expression(self) -> str: ...
    @overload
    def is_compiled(self) -> bool: ...
    @overload
    def is_compiled() -> bool: ...
    @overload
    def register_function(self, name: str, func) -> None: ...
    @overload
    def register_function(conststd, constclassstd) -> void: ...
    @overload
    def register_function(self, name: str, func) -> None: ...
    @overload
    def register_function(conststd, constclassstd) -> void: ...
    @overload
    def register_function(self, name: str, func) -> None: ...
    @overload
    def register_function(conststd, constclassstd) -> void: ...
    @overload
    def register_function(self, name: str, func) -> None: ...
    @overload
    def register_function(conststd, constclassstd) -> void: ...



from typing import Any

from typing import overload
import mrpt.pymrpt.mrpt.io
import mrpt.pymrpt.mrpt.io.CStream
import mrpt.pymrpt.mrpt.system

class CClientTCPSocket(mrpt.pymrpt.mrpt.io.CStream):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: CClientTCPSocket) -> None: ...
    @overload
    def __init__(self, arg0: CClientTCPSocket) -> None: ...
    @overload
    def Seek(self, off: int) -> int: ...
    @overload
    def Seek(self, off: int, org: mrpt.pymrpt.mrpt.io.CStream.TSeekOrigin) -> int: ...
    @overload
    def Seek(int64_t, enummrpt) -> uint64_t: ...
    def assign(self) -> CClientTCPSocket: ...
    @overload
    def close(self) -> None: ...
    @overload
    def close() -> void: ...
    @overload
    def connect(self, remotePartAddress: str, remotePartTCPPort: int) -> None: ...
    @overload
    def connect(self, remotePartAddress: str, remotePartTCPPort: int, timeout_ms: int) -> None: ...
    @overload
    def connect(conststd, unsignedshort, unsignedint) -> void: ...
    @overload
    def getPosition(self) -> int: ...
    @overload
    def getPosition() -> uint64_t: ...
    @overload
    def getReadPendingBytes(self) -> int: ...
    @overload
    def getReadPendingBytes() -> size_t: ...
    @overload
    def getSOSendBufffer(self) -> int: ...
    @overload
    def getSOSendBufffer() -> int: ...
    @overload
    def getTCPNoDelay(self) -> int: ...
    @overload
    def getTCPNoDelay() -> int: ...
    @overload
    def getTotalBytesCount(self) -> int: ...
    @overload
    def getTotalBytesCount() -> uint64_t: ...
    @overload
    def isConnected(self) -> bool: ...
    @overload
    def isConnected() -> bool: ...
    @overload
    def readAsync(self, Buffer: capsule, Count: int) -> int: ...
    @overload
    def readAsync(self, Buffer: capsule, Count: int, timeoutStart_ms: int) -> int: ...
    @overload
    def readAsync(self, Buffer: capsule, Count: int, timeoutStart_ms: int, timeoutBetween_ms: int) -> int: ...
    @overload
    def sendString(self, str: str) -> None: ...
    @overload
    def sendString(conststd) -> void: ...
    @overload
    def setSOSendBufffer(self, newValue: int) -> int: ...
    @overload
    def setSOSendBufffer(int) -> int: ...
    @overload
    def setTCPNoDelay(self, newValue: int) -> int: ...
    @overload
    def setTCPNoDelay(int) -> int: ...
    def writeAsync(self, *args, **kwargs) -> Any: ...

class CSerialPort(mrpt.pymrpt.mrpt.io.CStream):
    @overload
    def __init__(self, arg0: str) -> None: ...
    @overload
    def __init__(self, portName: str, openNow: bool) -> None: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: CSerialPort) -> None: ...
    @overload
    def __init__(self, arg0: CSerialPort) -> None: ...
    def Read(self, Buffer: capsule, Count: int) -> int: ...
    def ReadString(self, *args, **kwargs) -> Any: ...
    @overload
    def Seek(self, off: int) -> int: ...
    @overload
    def Seek(self, off: int, o: mrpt.pymrpt.mrpt.io.CStream.TSeekOrigin) -> int: ...
    @overload
    def Seek(int64_t, enummrpt) -> uint64_t: ...
    def Write(self, Buffer: capsule, Count: int) -> int: ...
    def assign(self) -> CSerialPort: ...
    @overload
    def close(self) -> None: ...
    @overload
    def close() -> void: ...
    @overload
    def getPosition(self) -> int: ...
    @overload
    def getPosition() -> uint64_t: ...
    @overload
    def getTotalBytesCount(self) -> int: ...
    @overload
    def getTotalBytesCount() -> uint64_t: ...
    @overload
    def isOpen(self) -> bool: ...
    @overload
    def isOpen() -> bool: ...
    @overload
    def open(self) -> None: ...
    @overload
    def open() -> void: ...
    @overload
    def open(self, COM_name: str) -> None: ...
    @overload
    def open(conststd) -> void: ...
    @overload
    def purgeBuffers(self) -> None: ...
    @overload
    def purgeBuffers() -> void: ...
    def setConfig(self, *args, **kwargs) -> Any: ...
    @overload
    def setSerialPortName(self, COM_name: str) -> None: ...
    @overload
    def setSerialPortName(conststd) -> void: ...
    def setTimeouts(self, ReadIntervalTimeout: int, ReadTotalTimeoutMultiplier: int, ReadTotalTimeoutConstant: int, WriteTotalTimeoutMultiplier: int, WriteTotalTimeoutConstant: int) -> None: ...

class CServerTCPSocket:
    @overload
    def __init__(self, listenPort: int) -> None: ...
    @overload
    def __init__(self, listenPort: int, IPaddress: str) -> None: ...
    @overload
    def __init__(self, listenPort: int, IPaddress: str, maxConnectionsWaiting: int) -> None: ...
    @overload
    def __init__(self, listenPort: int, IPaddress: str, maxConnectionsWaiting: int, verbosityLevel: mrpt.pymrpt.mrpt.system.VerbosityLevel) -> None: ...
    @overload
    def __init__(self, arg0: CServerTCPSocket) -> None: ...
    @overload
    def accept(self) -> CClientTCPSocket: ...
    @overload
    def accept(self, timeout_ms: int) -> CClientTCPSocket: ...
    def assign(self) -> CServerTCPSocket: ...
    @overload
    def isListening(self) -> bool: ...
    @overload
    def isListening() -> bool: ...

class TFTDIDevice:
    ftdi_description: str
    ftdi_manufacturer: str
    ftdi_serial: str
    usb_idProduct: int
    usb_idVendor: int
    usb_serialNumber: int
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: TFTDIDevice) -> None: ...
    def assign(self) -> TFTDIDevice: ...



from typing import Any, ClassVar, List

from typing import overload
import mrpt.pymrpt.mrpt.config
import mrpt.pymrpt.mrpt.img
import mrpt.pymrpt.mrpt.math
import mrpt.pymrpt.mrpt.poses
import mrpt.pymrpt.mrpt.system
import mrpt.pymrpt.mrpt.tfest
bothLists: TListIdx
descAny: TDescriptorType
descBLD: TDescriptorType
descLATCH: TDescriptorType
descLogPolarImages: TDescriptorType
descORB: TDescriptorType
descPolarImages: TDescriptorType
descSIFT: TDescriptorType
descSURF: TDescriptorType
descSpinImages: TDescriptorType
featAKAZE: TKeyPointMethod
featBeacon: TKeyPointMethod
featFAST: TKeyPointMethod
featHarris: TKeyPointMethod
featKLT: TKeyPointMethod
featLSD: TKeyPointMethod
featNotDefined: TKeyPointMethod
featORB: TKeyPointMethod
featSIFT: TKeyPointMethod
featSURF: TKeyPointMethod
firstList: TListIdx
secondList: TListIdx
status_IDLE: TFeatureTrackStatus
status_LOST: TFeatureTrackStatus
status_OOB: TFeatureTrackStatus
status_TRACKED: TFeatureTrackStatus

class CFeatureExtraction:
    class TOptions(mrpt.pymrpt.mrpt.config.CLoadableOptions):
        class TAKAZEOptions:
            descriptor_channels: int
            descriptor_size: int
            descriptor_type: int
            diffusivity: int
            nOctaveLayers: int
            nOctaves: int
            threshold: float
            @overload
            def __init__(self, arg0: CFeatureExtraction.TOptions.TAKAZEOptions) -> None: ...
            @overload
            def __init__(self) -> None: ...
            def assign(self) -> CFeatureExtraction.TOptions.TAKAZEOptions: ...
    
        class TBCDOptions:
            @overload
            def __init__(self, arg0: CFeatureExtraction.TOptions.TBCDOptions) -> None: ...
            @overload
            def __init__(self) -> None: ...
            def assign(self) -> CFeatureExtraction.TOptions.TBCDOptions: ...
    
        class TBLDOptions:
            ksize_: int
            numOfOctave: int
            reductionRatio: int
            widthOfBand: int
            @overload
            def __init__(self, arg0: CFeatureExtraction.TOptions.TBLDOptions) -> None: ...
            @overload
            def __init__(self) -> None: ...
            def assign(self) -> CFeatureExtraction.TOptions.TBLDOptions: ...
    
        class TFASTOptions:
            KLT_response_half_win_size: int
            min_distance: int
            nonmax_suppression: bool
            threshold: int
            use_KLT_response: bool
            @overload
            def __init__(self, arg0: CFeatureExtraction.TOptions.TFASTOptions) -> None: ...
            @overload
            def __init__(self) -> None: ...
            def assign(self) -> CFeatureExtraction.TOptions.TFASTOptions: ...
    
        class THarrisOptions:
            k: float
            min_distance: float
            radius: int
            sigma: float
            threshold: float
            @overload
            def __init__(self, arg0: CFeatureExtraction.TOptions.THarrisOptions) -> None: ...
            @overload
            def __init__(self) -> None: ...
            def assign(self) -> CFeatureExtraction.TOptions.THarrisOptions: ...
    
        class TKLTOptions:
            min_distance: float
            radius: int
            threshold: float
            @overload
            def __init__(self, arg0: CFeatureExtraction.TOptions.TKLTOptions) -> None: ...
            @overload
            def __init__(self) -> None: ...
            def assign(self) -> CFeatureExtraction.TOptions.TKLTOptions: ...
    
        class TLATCHOptions:
            bytes: int
            half_ssd_size: int
            rotationInvariance: bool
            @overload
            def __init__(self, arg0: CFeatureExtraction.TOptions.TLATCHOptions) -> None: ...
            @overload
            def __init__(self) -> None: ...
            def assign(self) -> CFeatureExtraction.TOptions.TLATCHOptions: ...
    
        class TLSDOptions:
            nOctaves: int
            scale: int
            @overload
            def __init__(self, arg0: CFeatureExtraction.TOptions.TLSDOptions) -> None: ...
            @overload
            def __init__(self) -> None: ...
            def assign(self) -> CFeatureExtraction.TOptions.TLSDOptions: ...
    
        class TLogPolarImagesOptions:
            num_angles: int
            radius: int
            rho_scale: float
            @overload
            def __init__(self, arg0: CFeatureExtraction.TOptions.TLogPolarImagesOptions) -> None: ...
            @overload
            def __init__(self) -> None: ...
            def assign(self) -> CFeatureExtraction.TOptions.TLogPolarImagesOptions: ...
    
        class TORBOptions:
            extract_patch: bool
            min_distance: int
            n_levels: int
            scale_factor: float
            @overload
            def __init__(self) -> None: ...
            @overload
            def __init__(self, arg0: CFeatureExtraction.TOptions.TORBOptions) -> None: ...
            def assign(self) -> CFeatureExtraction.TOptions.TORBOptions: ...
    
        class TPolarImagesOptions:
            bins_angle: int
            bins_distance: int
            radius: int
            @overload
            def __init__(self, arg0: CFeatureExtraction.TOptions.TPolarImagesOptions) -> None: ...
            @overload
            def __init__(self) -> None: ...
            def assign(self) -> CFeatureExtraction.TOptions.TPolarImagesOptions: ...
    
        class TSIFTOptions:
            edgeThreshold: float
            implementation: CFeatureExtraction.TSIFTImplementation
            octaveLayers: int
            threshold: float
            @overload
            def __init__(self) -> None: ...
            @overload
            def __init__(self, arg0: CFeatureExtraction.TOptions.TSIFTOptions) -> None: ...
            def assign(self) -> CFeatureExtraction.TOptions.TSIFTOptions: ...
    
        class TSURFOptions:
            hessianThreshold: int
            nLayersPerOctave: int
            nOctaves: int
            rotation_invariant: bool
            @overload
            def __init__(self) -> None: ...
            @overload
            def __init__(self, arg0: CFeatureExtraction.TOptions.TSURFOptions) -> None: ...
            def assign(self) -> CFeatureExtraction.TOptions.TSURFOptions: ...
    
        class TSpinImagesOptions:
            hist_size_distance: int
            hist_size_intensity: int
            radius: int
            std_dist: float
            std_intensity: float
            @overload
            def __init__(self, arg0: CFeatureExtraction.TOptions.TSpinImagesOptions) -> None: ...
            @overload
            def __init__(self) -> None: ...
            def assign(self) -> CFeatureExtraction.TOptions.TSpinImagesOptions: ...
        AKAZEOptions: Any
        BCDOptions: Any
        BLDOptions: Any
        FASTOptions: Any
        FIND_SUBPIXEL: bool
        KLTOptions: Any
        LATCHOptions: Any
        LSDOptions: Any
        LogPolarImagesOptions: Any
        ORBOptions: Any
        PolarImagesOptions: Any
        SIFTOptions: Any
        SURFOptions: Any
        SpinImagesOptions: Any
        addNewFeatures: bool
        featsType: TKeyPointMethod
        harrisOptions: Any
        patchSize: int
        useMask: bool
        @overload
        def __init__(self) -> None: ...
        @overload
        def __init__(self, ft: TKeyPointMethod) -> None: ...
        @overload
        def __init__(self, arg0: CFeatureExtraction.TOptions) -> None: ...
        @overload
        def __init__(self, arg0: CFeatureExtraction.TOptions) -> None: ...
        def assign(self) -> CFeatureExtraction.TOptions: ...
        @overload
        def loadFromConfigFile(self, c: mrpt.pymrpt.mrpt.config.CConfigFileBase, s: str) -> None: ...
        @overload
        def loadFromConfigFile(constclassmrpt, conststd) -> void: ...

    class TSIFTImplementation:
        __doc__: ClassVar[str] = ...  # read-only
        __members__: ClassVar[dict] = ...  # read-only
        OpenCV: ClassVar[CFeatureExtraction.TSIFTImplementation] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __and__(self, other: object) -> object: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> object: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: object) -> object: ...
        def __rand__(self, other: object) -> object: ...
        def __ror__(self, other: object) -> object: ...
        def __rxor__(self, other: object) -> object: ...
        def __setstate__(self, state: int) -> None: ...
        def __xor__(self, other: object) -> object: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...
    OpenCV: ClassVar[CFeatureExtraction.TSIFTImplementation] = ...
    options: Any
    profiler: mrpt.pymrpt.mrpt.system.CTimeLogger
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: CFeatureExtraction) -> None: ...
    def assign(self) -> CFeatureExtraction: ...
    @overload
    def computeDescriptors(self, in_img: mrpt.pymrpt.mrpt.img.CImage, inout_features: CFeatureList, in_descriptor_list: TDescriptorType) -> None: ...
    @overload
    def computeDescriptors(constclassmrpt, classmrpt, enummrpt) -> void: ...
    @overload
    def detectFeatures(self, img: mrpt.pymrpt.mrpt.img.CImage, feats: CFeatureList) -> None: ...
    @overload
    def detectFeatures(self, img: mrpt.pymrpt.mrpt.img.CImage, feats: CFeatureList, init_ID: int) -> None: ...
    @overload
    def detectFeatures(self, img: mrpt.pymrpt.mrpt.img.CImage, feats: CFeatureList, init_ID: int, nDesiredFeatures: int) -> None: ...
    @overload
    def detectFeatures(self, img: mrpt.pymrpt.mrpt.img.CImage, feats: CFeatureList, init_ID: int, nDesiredFeatures: int, ROI: TImageROI) -> None: ...

class CFeatureList:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: CFeatureList) -> None: ...
    def assign(self) -> CFeatureList: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    @overload
    def copyListFrom(self, otherList: CFeatureList) -> None: ...
    @overload
    def copyListFrom(constclassmrpt) -> void: ...
    @overload
    def empty(self) -> bool: ...
    @overload
    def empty() -> bool: ...
    @overload
    def getFeatureID(self, i: int) -> int: ...
    @overload
    def getFeatureID(size_t) -> unsignedlong: ...
    @overload
    def getFeatureResponse(self, i: int) -> float: ...
    @overload
    def getFeatureResponse(size_t) -> float: ...
    def getFeatureX(self, i: int) -> float: ...
    @overload
    def getFeatureY(self, i: int) -> float: ...
    @overload
    def getFeatureY(size_t) -> float: ...
    @overload
    def getMaxID(self) -> int: ...
    @overload
    def getMaxID() -> unsignedlong: ...
    @overload
    def getScale(self, i: int) -> float: ...
    @overload
    def getScale(size_t) -> float: ...
    def getTrackStatus(self, i: int) -> TFeatureTrackStatus: ...
    def get_type(self) -> TKeyPointMethod: ...
    @overload
    def isPointFeature(self, i: int) -> bool: ...
    @overload
    def isPointFeature(size_t) -> bool: ...
    def kdtree_distance(self, p1: float, idx_p2: int, size: int) -> float: ...
    @overload
    def kdtree_get_point_count(self) -> int: ...
    @overload
    def kdtree_get_point_count() -> size_t: ...
    @overload
    def kdtree_get_pt(self, idx: int, dim: int) -> float: ...
    @overload
    def kdtree_get_pt(size_t, int) -> float: ...
    @overload
    def loadFromTextFile(self, fileName: str) -> None: ...
    @overload
    def loadFromTextFile(conststd) -> void: ...
    @overload
    def mark_as_outdated(self) -> None: ...
    @overload
    def mark_as_outdated() -> void: ...
    @overload
    def mark_kdtree_as_outdated(self) -> None: ...
    @overload
    def mark_kdtree_as_outdated() -> void: ...
    @overload
    def resize(self, N: int) -> None: ...
    @overload
    def resize(size_t) -> void: ...
    @overload
    def saveToTextFile(self, fileName: str) -> None: ...
    @overload
    def saveToTextFile(self, fileName: str, APPEND: bool) -> None: ...
    @overload
    def saveToTextFile(conststd, bool) -> void: ...
    @overload
    def setFeatureID(self, i: int, id: int) -> None: ...
    @overload
    def setFeatureID(size_t, unsignedlong) -> void: ...
    @overload
    def setFeatureResponse(self, i: int, r: float) -> None: ...
    @overload
    def setFeatureResponse(size_t, float) -> void: ...
    @overload
    def setFeatureX(self, i: int, x: float) -> None: ...
    @overload
    def setFeatureX(size_t, float) -> void: ...
    @overload
    def setFeatureXf(self, i: int, x: float) -> None: ...
    @overload
    def setFeatureXf(size_t, float) -> void: ...
    @overload
    def setFeatureY(self, i: int, y: float) -> None: ...
    @overload
    def setFeatureY(size_t, float) -> void: ...
    @overload
    def setFeatureYf(self, i: int, y: float) -> None: ...
    @overload
    def setFeatureYf(size_t, float) -> void: ...
    @overload
    def setScale(self, i: int, s: int) -> None: ...
    @overload
    def setScale(size_t, uint8_t) -> void: ...
    @overload
    def setTrackStatus(self, i: int, s: TFeatureTrackStatus) -> None: ...
    @overload
    def setTrackStatus(size_t, enummrpt) -> void: ...
    @overload
    def size(self) -> int: ...
    @overload
    def size() -> size_t: ...

class CMatchedFeatureList:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: CMatchedFeatureList) -> None: ...
    def assign(self) -> CMatchedFeatureList: ...
    def getBothFeatureLists(self, list1: CFeatureList, list2: CFeatureList) -> None: ...
    def getMaxID(self, idx: TListIdx, firstListID: int, secondListID: int) -> None: ...
    def get_type(self) -> TKeyPointMethod: ...
    @overload
    def saveToTextFile(self, fileName: str) -> None: ...
    @overload
    def saveToTextFile(conststd) -> void: ...
    def setLeftMaxID(self, leftID: int) -> None: ...
    def setMaxIDs(self, leftID: int, rightID: int) -> None: ...
    def setRightMaxID(self, rightID: int) -> None: ...
    @overload
    def updateMaxID(self, idx: TListIdx) -> None: ...
    @overload
    def updateMaxID(constenummrpt) -> void: ...

class TDescriptorType:
    __doc__: ClassVar[str] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    __entries: ClassVar[dict] = ...
    descAny: ClassVar[TDescriptorType] = ...
    descBLD: ClassVar[TDescriptorType] = ...
    descLATCH: ClassVar[TDescriptorType] = ...
    descLogPolarImages: ClassVar[TDescriptorType] = ...
    descORB: ClassVar[TDescriptorType] = ...
    descPolarImages: ClassVar[TDescriptorType] = ...
    descSIFT: ClassVar[TDescriptorType] = ...
    descSURF: ClassVar[TDescriptorType] = ...
    descSpinImages: ClassVar[TDescriptorType] = ...
    def __init__(self, value: int) -> None: ...
    def __and__(self, other: object) -> object: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __gt__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __invert__(self) -> object: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __or__(self, other: object) -> object: ...
    def __rand__(self, other: object) -> object: ...
    def __ror__(self, other: object) -> object: ...
    def __rxor__(self, other: object) -> object: ...
    def __setstate__(self, state: int) -> None: ...
    def __xor__(self, other: object) -> object: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class TFeatureObservation:
    id_feature: int
    id_frame: int
    px: mrpt.pymrpt.mrpt.img.TPixelCoordf
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, _id_feature: int, _id_frame: int, _px: mrpt.pymrpt.mrpt.img.TPixelCoordf) -> None: ...
    @overload
    def __init__(self, arg0: TFeatureObservation) -> None: ...
    def assign(self) -> TFeatureObservation: ...

class TFeatureTrackStatus:
    __doc__: ClassVar[str] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    __entries: ClassVar[dict] = ...
    status_IDLE: ClassVar[TFeatureTrackStatus] = ...
    status_LOST: ClassVar[TFeatureTrackStatus] = ...
    status_OOB: ClassVar[TFeatureTrackStatus] = ...
    status_TRACKED: ClassVar[TFeatureTrackStatus] = ...
    def __init__(self, value: int) -> None: ...
    def __and__(self, other: object) -> object: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __gt__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __invert__(self) -> object: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __or__(self, other: object) -> object: ...
    def __rand__(self, other: object) -> object: ...
    def __ror__(self, other: object) -> object: ...
    def __rxor__(self, other: object) -> object: ...
    def __setstate__(self, state: int) -> None: ...
    def __xor__(self, other: object) -> object: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class TImageCalibData:
    detected_corners: List[mrpt.pymrpt.mrpt.img.TPixelCoordf]
    img_checkboard: mrpt.pymrpt.mrpt.img.CImage
    img_original: mrpt.pymrpt.mrpt.img.CImage
    img_rectified: mrpt.pymrpt.mrpt.img.CImage
    projectedPoints_distorted: List[mrpt.pymrpt.mrpt.img.TPixelCoordf]
    projectedPoints_undistorted: List[mrpt.pymrpt.mrpt.img.TPixelCoordf]
    reconstructed_camera_pose: mrpt.pymrpt.mrpt.poses.CPose3D
    @overload
    def __init__(self, arg0: TImageCalibData) -> None: ...
    @overload
    def __init__(self) -> None: ...
    def assign(self) -> TImageCalibData: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...

class TImageROI:
    xMax: int
    xMin: int
    yMax: int
    yMin: int
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, x1: int, x2: int, y1: int, y2: int) -> None: ...
    @overload
    def __init__(self, arg0: TImageROI) -> None: ...

class TKeyPointMethod:
    __doc__: ClassVar[str] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    __entries: ClassVar[dict] = ...
    featAKAZE: ClassVar[TKeyPointMethod] = ...
    featBeacon: ClassVar[TKeyPointMethod] = ...
    featFAST: ClassVar[TKeyPointMethod] = ...
    featHarris: ClassVar[TKeyPointMethod] = ...
    featKLT: ClassVar[TKeyPointMethod] = ...
    featLSD: ClassVar[TKeyPointMethod] = ...
    featNotDefined: ClassVar[TKeyPointMethod] = ...
    featORB: ClassVar[TKeyPointMethod] = ...
    featSIFT: ClassVar[TKeyPointMethod] = ...
    featSURF: ClassVar[TKeyPointMethod] = ...
    def __init__(self, value: int) -> None: ...
    def __and__(self, other: object) -> object: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __gt__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __invert__(self) -> object: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __or__(self, other: object) -> object: ...
    def __rand__(self, other: object) -> object: ...
    def __ror__(self, other: object) -> object: ...
    def __rxor__(self, other: object) -> object: ...
    def __setstate__(self, state: int) -> None: ...
    def __xor__(self, other: object) -> object: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class TKeyPointTraits_mrpt_vision_TKeyPoint_templ_mrpt_img_TPixelCoord_t:
    def __init__(self) -> None: ...
    def f2coord(self, *args, **kwargs) -> Any: ...

class TKeyPointTraits_mrpt_vision_TKeyPoint_templ_mrpt_img_TPixelCoordf_t:
    def __init__(self) -> None: ...
    def f2coord(self, *args, **kwargs) -> Any: ...

class TKeyPoint_templ_mrpt_img_TPixelCoordf_t:
    ID: int
    octave: int
    pt: mrpt.pymrpt.mrpt.img.TPixelCoordf
    response: float
    track_status: TFeatureTrackStatus
    user_flags: int
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: TKeyPoint_templ_mrpt_img_TPixelCoordf_t) -> None: ...
    def assign(self) -> TKeyPoint_templ_mrpt_img_TPixelCoordf_t: ...

class TListIdx:
    __doc__: ClassVar[str] = ...  # read-only
    __members__: ClassVar[dict] = ...  # read-only
    __entries: ClassVar[dict] = ...
    bothLists: ClassVar[TListIdx] = ...
    firstList: ClassVar[TListIdx] = ...
    secondList: ClassVar[TListIdx] = ...
    def __init__(self, value: int) -> None: ...
    def __and__(self, other: object) -> object: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __gt__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __invert__(self) -> object: ...
    def __le__(self, other: object) -> bool: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __or__(self, other: object) -> object: ...
    def __rand__(self, other: object) -> object: ...
    def __ror__(self, other: object) -> object: ...
    def __rxor__(self, other: object) -> object: ...
    def __setstate__(self, state: int) -> None: ...
    def __xor__(self, other: object) -> object: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> int: ...

class TMatchingOptions(mrpt.pymrpt.mrpt.config.CLoadableOptions):
    class TMatchingMethod:
        __doc__: ClassVar[str] = ...  # read-only
        __members__: ClassVar[dict] = ...  # read-only
        __entries: ClassVar[dict] = ...
        mmCorrelation: ClassVar[TMatchingOptions.TMatchingMethod] = ...
        mmDescriptorORB: ClassVar[TMatchingOptions.TMatchingMethod] = ...
        mmDescriptorSIFT: ClassVar[TMatchingOptions.TMatchingMethod] = ...
        mmDescriptorSURF: ClassVar[TMatchingOptions.TMatchingMethod] = ...
        mmSAD: ClassVar[TMatchingOptions.TMatchingMethod] = ...
        def __init__(self, value: int) -> None: ...
        def __and__(self, other: object) -> object: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> object: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: object) -> object: ...
        def __rand__(self, other: object) -> object: ...
        def __ror__(self, other: object) -> object: ...
        def __rxor__(self, other: object) -> object: ...
        def __setstate__(self, state: int) -> None: ...
        def __xor__(self, other: object) -> object: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...
    mmCorrelation: ClassVar[TMatchingOptions.TMatchingMethod] = ...
    mmDescriptorORB: ClassVar[TMatchingOptions.TMatchingMethod] = ...
    mmDescriptorSIFT: ClassVar[TMatchingOptions.TMatchingMethod] = ...
    mmDescriptorSURF: ClassVar[TMatchingOptions.TMatchingMethod] = ...
    mmSAD: ClassVar[TMatchingOptions.TMatchingMethod] = ...
    __hash__: ClassVar[None] = ...
    EDD_RATIO: float
    EDSD_RATIO: float
    F: mrpt.pymrpt.mrpt.math.CMatrixFixed_double_3UL_3UL_t
    SAD_RATIO: float
    addMatches: bool
    enable_robust_1to1_match: bool
    epipolar_TH: float
    estimateDepth: bool
    hasFundamentalMatrix: bool
    matching_method: TMatchingOptions.TMatchingMethod
    maxDepthThreshold: float
    maxEDD_TH: float
    maxEDSD_TH: float
    maxORB_dist: float
    maxSAD_TH: float
    max_disp: float
    minCC_TH: float
    minDCC_TH: float
    min_disp: float
    parallelOpticalAxis: bool
    rCC_TH: float
    useDisparityLimits: bool
    useEpipolarRestriction: bool
    useXRestriction: bool
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: TMatchingOptions) -> None: ...
    @overload
    def __init__(self, arg0: TMatchingOptions) -> None: ...
    def assign(self) -> TMatchingOptions: ...
    @overload
    def loadFromConfigFile(self, source: mrpt.pymrpt.mrpt.config.CConfigFileBase, section: str) -> None: ...
    @overload
    def loadFromConfigFile(constclassmrpt, conststd) -> void: ...
    def __eq__(self, o: TMatchingOptions) -> bool: ...

class TMultiResDescMatchOptions(mrpt.pymrpt.mrpt.config.CLoadableOptions):
    highScl1: int
    highScl2: int
    lastSeenThreshold: int
    lowScl1: int
    lowScl2: int
    matchingRatioThreshold: float
    matchingThreshold: float
    minFeaturesToBeLost: int
    minFeaturesToFind: int
    oriThreshold: float
    searchAreaSize: int
    timesSeenThreshold: int
    useDepthFilter: bool
    useOriFilter: bool
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, _useOriFilter: bool, _oriThreshold: float, _useDepthFilter: bool, _th: float, _th2: float, _lwscl1: int, _lwscl2: int, _hwscl1: int, _hwscl2: int, _searchAreaSize: int, _lsth: int, _tsth: int, _minFeaturesToFind: int, _minFeaturesToBeLost: int) -> None: ...
    @overload
    def __init__(self, arg0: TMultiResDescMatchOptions) -> None: ...
    @overload
    def __init__(self, arg0: TMultiResDescMatchOptions) -> None: ...
    def assign(self) -> TMultiResDescMatchOptions: ...
    @overload
    def loadFromConfigFile(self, cfg: mrpt.pymrpt.mrpt.config.CConfigFileBase, section: str) -> None: ...
    @overload
    def loadFromConfigFile(constclassmrpt, conststd) -> void: ...
    @overload
    def saveToConfigFile(self, cfg: mrpt.pymrpt.mrpt.config.CConfigFileBase, section: str) -> None: ...
    @overload
    def saveToConfigFile(classmrpt, conststd) -> void: ...

class TMultiResDescOptions(mrpt.pymrpt.mrpt.config.CLoadableOptions):
    basePSize: int
    baseline: float
    blurImage: bool
    comHScl: int
    comLScl: int
    computeDepth: bool
    computeHashCoeffs: bool
    cropValue: float
    cx: float
    cy: float
    fx: float
    scales: List[float]
    sg1: float
    sg2: float
    sg3: float
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: TMultiResDescOptions) -> None: ...
    @overload
    def __init__(self, arg0: TMultiResDescOptions) -> None: ...
    def assign(self) -> TMultiResDescOptions: ...
    @overload
    def loadFromConfigFile(self, source: mrpt.pymrpt.mrpt.config.CConfigFileBase, section: str) -> None: ...
    @overload
    def loadFromConfigFile(constclassmrpt, conststd) -> void: ...
    @overload
    def saveToConfigFile(self, cfg: mrpt.pymrpt.mrpt.config.CConfigFileBase, section: str) -> None: ...
    @overload
    def saveToConfigFile(classmrpt, conststd) -> void: ...

class TMultiResMatchingOutput:
    firstListCorrespondences: List[int]
    firstListDistance: List[float]
    firstListFoundScales: List[int]
    nMatches: int
    secondListCorrespondences: List[int]
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: TMultiResMatchingOutput) -> None: ...
    def assign(self) -> TMultiResMatchingOutput: ...

class TROI:
    xMax: float
    xMin: float
    yMax: float
    yMin: float
    zMax: float
    zMin: float
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, x1: float, x2: float, y1: float, y2: float, z1: float, z2: float) -> None: ...

class TRelativeFeaturePos:
    id_frame_base: int
    pos: Any
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, _id_frame_base: int, _pos) -> None: ...

class TSequenceFeatureObservations:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, size: int) -> None: ...
    @overload
    def __init__(self, arg0: TSequenceFeatureObservations) -> None: ...
    def assign(self) -> TSequenceFeatureObservations: ...
    @overload
    def decimateCameraFrames(self, decimate_ratio: int) -> None: ...
    @overload
    def decimateCameraFrames(size_t) -> void: ...
    @overload
    def loadFromTextFile(self, filName: str) -> None: ...
    @overload
    def loadFromTextFile(conststd) -> void: ...
    @overload
    def removeFewObservedFeatures(self) -> int: ...
    @overload
    def removeFewObservedFeatures(self, minNumObservations: int) -> int: ...
    @overload
    def removeFewObservedFeatures(size_t) -> size_t: ...
    @overload
    def saveToTextFile(self, filName: str) -> None: ...
    @overload
    def saveToTextFile(self, filName: str, skipFirstCommentLine: bool) -> None: ...
    @overload
    def saveToTextFile(conststd, bool) -> void: ...

class TStereoSystemParams(mrpt.pymrpt.mrpt.config.CLoadableOptions):
    class TUnc_Prop_Method:
        __doc__: ClassVar[str] = ...  # read-only
        __members__: ClassVar[dict] = ...  # read-only
        Prop_Linear: ClassVar[TStereoSystemParams.TUnc_Prop_Method] = ...
        Prop_SUT: ClassVar[TStereoSystemParams.TUnc_Prop_Method] = ...
        Prop_UT: ClassVar[TStereoSystemParams.TUnc_Prop_Method] = ...
        __entries: ClassVar[dict] = ...
        def __init__(self, value: int) -> None: ...
        def __and__(self, other: object) -> object: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __getstate__(self) -> int: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> object: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: object) -> object: ...
        def __rand__(self, other: object) -> object: ...
        def __ror__(self, other: object) -> object: ...
        def __rxor__(self, other: object) -> object: ...
        def __setstate__(self, state: int) -> None: ...
        def __xor__(self, other: object) -> object: ...
        @property
        def name(self) -> str: ...
        @property
        def value(self) -> int: ...
    Prop_Linear: ClassVar[TStereoSystemParams.TUnc_Prop_Method] = ...
    Prop_SUT: ClassVar[TStereoSystemParams.TUnc_Prop_Method] = ...
    Prop_UT: ClassVar[TStereoSystemParams.TUnc_Prop_Method] = ...
    F: mrpt.pymrpt.mrpt.math.CMatrixFixed_double_3UL_3UL_t
    K: mrpt.pymrpt.mrpt.math.CMatrixFixed_double_3UL_3UL_t
    baseline: float
    factor_a: float
    factor_b: float
    factor_k: float
    maxY: float
    maxZ: float
    minZ: float
    stdDisp: float
    stdPixel: float
    uncPropagation: TStereoSystemParams.TUnc_Prop_Method
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: TStereoSystemParams) -> None: ...
    @overload
    def __init__(self, arg0: TStereoSystemParams) -> None: ...
    def assign(self) -> TStereoSystemParams: ...
    @overload
    def loadFromConfigFile(self, source: mrpt.pymrpt.mrpt.config.CConfigFileBase, section: str) -> None: ...
    @overload
    def loadFromConfigFile(constclassmrpt, conststd) -> void: ...

def addFeaturesToImage(*args, **kwargs) -> Any: ...
def buildIntrinsicParamsMatrix(focalLengthX: float, focalLengthY: float, centerX: float, centerY: float) -> mrpt.pymrpt.mrpt.math.CMatrixFixed_double_3UL_3UL_t: ...
def computeMainOrientation(*args, **kwargs) -> Any: ...
def computeMsd(list: mrpt.pymrpt.mrpt.tfest.TMatchingPairListTempl_float_t, Rt: mrpt.pymrpt.mrpt.poses.CPose3D) -> float: ...
def computeSAD(patch1: mrpt.pymrpt.mrpt.img.CImage, patch2: mrpt.pymrpt.mrpt.img.CImage) -> float: ...
def computeStereoRectificationMaps(cam1: mrpt.pymrpt.mrpt.img.TCamera, cam2: mrpt.pymrpt.mrpt.img.TCamera, rightCameraPose: mrpt.pymrpt.mrpt.poses.CPose3D, outMap1x: capsule, outMap1y: capsule, outMap2x: capsule, outMap2y: capsule) -> None: ...
def matchFeatures(*args, **kwargs) -> Any: ...
def normalizeImage(*args, **kwargs) -> Any: ...
def pixelTo3D(*args, **kwargs) -> Any: ...
def projectMatchedFeatures(*args, **kwargs) -> Any: ...



from typing import Any

from typing import overload

class duration_long_std_ratio_1_10000000_t:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: duration_long_std_ratio_1_10000000_t) -> None: ...
    def assign(self) -> duration_long_std_ratio_1_10000000_t: ...
    @overload
    def count(self) -> int: ...
    @overload
    def count() -> long: ...
    def max(self, *args, **kwargs) -> Any: ...
    def min(self, *args, **kwargs) -> Any: ...
    def post_decrement(self) -> duration_long_std_ratio_1_10000000_t: ...
    def post_increment(self) -> duration_long_std_ratio_1_10000000_t: ...
    def pre_decrement(self) -> duration_long_std_ratio_1_10000000_t: ...
    def pre_increment(self) -> duration_long_std_ratio_1_10000000_t: ...
    def zero(self, *args, **kwargs) -> Any: ...
    def __iadd__(self, __d: duration_long_std_ratio_1_10000000_t) -> duration_long_std_ratio_1_10000000_t: ...
    def __imul__(self, __rhs: int) -> duration_long_std_ratio_1_10000000_t: ...
    def __isub__(self, __d: duration_long_std_ratio_1_10000000_t) -> duration_long_std_ratio_1_10000000_t: ...
    def __itruediv__(self, __rhs: int) -> duration_long_std_ratio_1_10000000_t: ...
    def __neg__(self) -> duration_long_std_ratio_1_10000000_t: ...
    def __pos__(self) -> duration_long_std_ratio_1_10000000_t: ...

class time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, __dur: duration_long_std_ratio_1_10000000_t) -> None: ...
    @overload
    def __init__(self, arg0: time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t) -> None: ...
    def assign(self) -> time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t: ...
    def max(self, *args, **kwargs) -> Any: ...
    def min(self, *args, **kwargs) -> Any: ...
    def time_since_epoch(self) -> duration_long_std_ratio_1_10000000_t: ...
    def to_double(self) -> float: ...
    def __iadd__(self, __dur: duration_long_std_ratio_1_10000000_t) -> time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t: ...
    def __isub__(self, __dur: duration_long_std_ratio_1_10000000_t) -> time_point_mrpt_Clock_std_chrono_duration_long_std_ratio_1_10000000_t: ...



from typing import Any

class TEnumType_mrpt_bayes_TKFMethod_t:
    def __init__(self) -> None: ...
    def getBimap(self, *args, **kwargs) -> Any: ...
    def name2value(self, *args, **kwargs) -> Any: ...
    def value2name(self, *args, **kwargs) -> Any: ...

class TEnumType_mrpt_system_VerbosityLevel_t:
    def __init__(self) -> None: ...
    def getBimap(self, *args, **kwargs) -> Any: ...
    def name2value(self, *args, **kwargs) -> Any: ...
    def value2name(self, *args, **kwargs) -> Any: ...



#!/usr/bin/env python3

# ---------------------------------------------------------------------
# Install python3-pymrpt, ros-$ROS_DISTRO-python-mrpt,
# ros-$ROS_DISTRO-mrpt2, or test with a local build with:
# export PYTHONPATH=$HOME/code/mrpt/build-Release/:$PYTHONPATH
# ---------------------------------------------------------------------

from mrpt.pymrpt import mrpt
from math import radians

p1 = mrpt.poses.CPose3D.FromXYZYawPitchRoll(
    1.0, 2.0, 0, radians(90), radians(0), radians(0))
p2 = mrpt.poses.CPose3D.FromXYZYawPitchRoll(
    3.0, 0.0, 0, radians(0.0), radians(0), radians(0))

p3 = p1 + p2
p4 = p3 - p1

print('p1             : ' + str(p1))
print('p2             : ' + str(p2))
print('p1(+)p2        : ' + str(p3))
print('(p1(+)p2)(-)p1 : ' + str(p4))



from typing import overload
import mrpt.pymrpt.mrpt.img
import mrpt.pymrpt.mrpt.obs

@overload
def example2DRangeScan(s: mrpt.pymrpt.mrpt.obs.CObservation2DRangeScan) -> None: ...
@overload
def example2DRangeScan(s: mrpt.pymrpt.mrpt.obs.CObservation2DRangeScan, i: int) -> None: ...
@overload
def example2DRangeScan(classmrpt, int) -> void: ...
@overload
def exampleImage(im: mrpt.pymrpt.mrpt.img.CImage) -> None: ...
@overload
def exampleImage(im: mrpt.pymrpt.mrpt.img.CImage, i: int) -> None: ...
@overload
def exampleImage(classmrpt, int) -> void: ...



from typing import Any, List

from typing import overload
import mrpt.pymrpt.mrpt.poses

class TMatchingPairListTempl_float_t:
    @overload
    def __init__(self, arg0: TMatchingPairListTempl_float_t) -> None: ...
    @overload
    def __init__(self) -> None: ...
    def assign(self) -> TMatchingPairListTempl_float_t: ...
    @overload
    def dumpToFile(self, fileName: str) -> None: ...
    @overload
    def dumpToFile(conststd) -> void: ...
    @overload
    def filterUniqueRobustPairs(self, num_elements_this_map: int, out_filtered_list: TMatchingPairListTempl_float_t) -> None: ...
    @overload
    def filterUniqueRobustPairs(size_t, classmrpt) -> void: ...
    @overload
    def indexOtherMapHasCorrespondence(self, idx: int) -> bool: ...
    @overload
    def indexOtherMapHasCorrespondence(size_t) -> bool: ...
    @overload
    def overallSquareError(self, q: mrpt.pymrpt.mrpt.poses.CPose2D) -> float: ...
    @overload
    def overallSquareError(constclassmrpt) -> float: ...
    @overload
    def overallSquareError(self, q: mrpt.pymrpt.mrpt.poses.CPose3D) -> float: ...
    @overload
    def overallSquareError(constclassmrpt) -> float: ...
    @overload
    def saveAsMATLABScript(self, filName: str) -> None: ...
    @overload
    def saveAsMATLABScript(conststd) -> void: ...

class TPotentialMatch:
    idx_other: int
    idx_this: int
    def __init__(self) -> None: ...

class TSE2RobustParams:
    max_rmse_to_end: float
    probability_find_good_model: float
    ransac_algorithmForLandmarks: bool
    ransac_fuseByCorrsMatch: bool
    ransac_fuseMaxDiffPhi: float
    ransac_fuseMaxDiffXY: float
    ransac_mahalanobisDistanceThreshold: float
    ransac_maxSetSize: int
    ransac_minSetSize: int
    ransac_min_nSimulations: int
    ransac_nSimulations: int
    user_individual_compat_callback: Any
    verbose: bool
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: TSE2RobustParams) -> None: ...
    def assign(self) -> TSE2RobustParams: ...

class TSE2RobustResult:
    largestSubSet: TMatchingPairListTempl_float_t
    ransac_iters: int
    transformation: mrpt.pymrpt.mrpt.poses.CPosePDFSOG
    def __init__(self) -> None: ...

class TSE3RobustParams:
    forceScaleToUnity: bool
    ransac_maxSetSizePct: float
    ransac_minSetSize: int
    ransac_nmaxSimulations: int
    ransac_threshold_ang: float
    ransac_threshold_lin: float
    ransac_threshold_scale: float
    user_individual_compat_callback: Any
    verbose: bool
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: TSE3RobustParams) -> None: ...
    def assign(self) -> TSE3RobustParams: ...

class TSE3RobustResult:
    inliers_idx: List[int]
    scale: float
    transformation: mrpt.pymrpt.mrpt.poses.CPose3DQuat
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: TSE3RobustResult) -> None: ...
    def assign(self) -> TSE3RobustResult: ...

def se2_l2(*args, **kwargs) -> Any: ...
def se2_l2_robust(*args, **kwargs) -> Any: ...
def se3_l2(*args, **kwargs) -> Any: ...
def se3_l2_robust(*args, **kwargs) -> Any: ...



from typing import overload

@overload
def HEIGHTGRIDMAP_EXPORT3D_AS_MESH(value: bool) -> None: ...
@overload
def HEIGHTGRIDMAP_EXPORT3D_AS_MESH(bool) -> void: ...
@overload
def HEIGHTGRIDMAP_EXPORT3D_AS_MESH() -> bool: ...
@overload
def HEIGHTGRIDMAP_EXPORT3D_AS_MESH() -> bool: ...
@overload
def OCTREE_RENDER_MAX_DENSITY_POINTS_PER_SQPIXEL(value: float) -> None: ...
@overload
def OCTREE_RENDER_MAX_DENSITY_POINTS_PER_SQPIXEL(float) -> void: ...
@overload
def OCTREE_RENDER_MAX_DENSITY_POINTS_PER_SQPIXEL() -> float: ...
@overload
def OCTREE_RENDER_MAX_DENSITY_POINTS_PER_SQPIXEL() -> float: ...
@overload
def OCTREE_RENDER_MAX_POINTS_PER_NODE() -> int: ...
@overload
def OCTREE_RENDER_MAX_POINTS_PER_NODE() -> size_t: ...
@overload
def OCTREE_RENDER_MAX_POINTS_PER_NODE(value: int) -> None: ...
@overload
def OCTREE_RENDER_MAX_POINTS_PER_NODE(size_t) -> void: ...
@overload
def USE_SUT_EULER2QUAT_CONVERSION(value: bool) -> None: ...
@overload
def USE_SUT_EULER2QUAT_CONVERSION(bool) -> void: ...
@overload
def USE_SUT_EULER2QUAT_CONVERSION() -> bool: ...
@overload
def USE_SUT_EULER2QUAT_CONVERSION() -> bool: ...
@overload
def USE_SUT_QUAT2EULER_CONVERSION(value: bool) -> None: ...
@overload
def USE_SUT_QUAT2EULER_CONVERSION(bool) -> void: ...
@overload
def USE_SUT_QUAT2EULER_CONVERSION() -> bool: ...
@overload
def USE_SUT_QUAT2EULER_CONVERSION() -> bool: ...



from typing import List

from typing import overload
import mrpt.pymrpt.mrpt.system

class CConfigFile(CConfigFileBase):
    @overload
    def __init__(self, fileName: str) -> None: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg0: CConfigFile) -> None: ...
    @overload
    def __init__(self, arg0: CConfigFile) -> None: ...
    def assign(self) -> CConfigFile: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    @overload
    def discardSavingChanges(self) -> None: ...
    @overload
    def discardSavingChanges() -> void: ...
    @overload
    def getAllKeys(self, section: str, keys: List[str]) -> None: ...
    @overload
    def getAllKeys(conststd, classstd) -> void: ...
    @overload
    def getAllSections(self, sections: List[str]) -> None: ...
    @overload
    def getAllSections(classstd) -> void: ...
    def getAssociatedFile(self) -> str: ...
    @overload
    def setFileName(self, fil_path: str) -> None: ...
    @overload
    def setFileName(conststd) -> void: ...
    @overload
    def writeNow(self) -> None: ...
    @overload
    def writeNow() -> void: ...

class CConfigFileBase:
    @overload
    def __init__(self, arg0: CConfigFileBase) -> None: ...
    @overload
    def __init__(self) -> None: ...
    def assign(self) -> CConfigFileBase: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    @overload
    def getAllKeys(self, section: str, keys: List[str]) -> None: ...
    @overload
    def getAllKeys(conststd, classstd) -> void: ...
    @overload
    def getAllSections(self, sections: List[str]) -> None: ...
    @overload
    def getAllSections(classstd) -> void: ...
    def getContentAsYAML(self) -> str: ...
    def keyExists(self, section: str, key: str) -> bool: ...
    def keys(self, section: str) -> List[str]: ...
    @overload
    def read_bool(self, section: str, name: str, defaultValue: bool) -> bool: ...
    @overload
    def read_bool(self, section: str, name: str, defaultValue: bool, failIfNotFound: bool) -> bool: ...
    @overload
    def read_double(self, section: str, name: str, defaultValue: float) -> float: ...
    @overload
    def read_double(self, section: str, name: str, defaultValue: float, failIfNotFound: bool) -> float: ...
    @overload
    def read_enum(self, section: str, name: str, defaultValue: mrpt.pymrpt.mrpt.system.VerbosityLevel) -> mrpt.pymrpt.mrpt.system.VerbosityLevel: ...
    @overload
    def read_enum(self, section: str, name: str, defaultValue: mrpt.pymrpt.mrpt.system.VerbosityLevel, failIfNotFound: bool) -> mrpt.pymrpt.mrpt.system.VerbosityLevel: ...
    @overload
    def read_float(self, section: str, name: str, defaultValue: float) -> float: ...
    @overload
    def read_float(self, section: str, name: str, defaultValue: float, failIfNotFound: bool) -> float: ...
    @overload
    def read_int(self, section: str, name: str, defaultValue: int) -> int: ...
    @overload
    def read_int(self, section: str, name: str, defaultValue: int, failIfNotFound: bool) -> int: ...
    @overload
    def read_string(self, section: str, name: str, defaultValue: str) -> str: ...
    @overload
    def read_string(self, section: str, name: str, defaultValue: str, failIfNotFound: bool) -> str: ...
    @overload
    def read_string_first_word(self, section: str, name: str, defaultValue: str) -> str: ...
    @overload
    def read_string_first_word(self, section: str, name: str, defaultValue: str, failIfNotFound: bool) -> str: ...
    @overload
    def read_uint64_t(self, section: str, name: str, defaultValue: int) -> int: ...
    @overload
    def read_uint64_t(self, section: str, name: str, defaultValue: int, failIfNotFound: bool) -> int: ...
    @overload
    def sectionExists(self, section_name: str) -> bool: ...
    @overload
    def sectionExists(conststd) -> bool: ...
    def sections(self) -> List[str]: ...
    @overload
    def setContentFromYAML(self, yaml_block: str) -> None: ...
    @overload
    def setContentFromYAML(conststd) -> void: ...
    @overload
    def write(self, section: str, name: str, value: float) -> None: ...
    @overload
    def write(self, section: str, name: str, value: float, name_padding_width: int) -> None: ...
    @overload
    def write(self, section: str, name: str, value: float, name_padding_width: int, value_padding_width: int) -> None: ...
    @overload
    def write(self, section: str, name: str, value: float, name_padding_width: int, value_padding_width: int, comment: str) -> None: ...
    @overload
    def write(self, section: str, name: str, value: float) -> None: ...
    @overload
    def write(self, section: str, name: str, value: float, name_padding_width: int) -> None: ...
    @overload
    def write(self, section: str, name: str, value: float, name_padding_width: int, value_padding_width: int) -> None: ...
    @overload
    def write(self, section: str, name: str, value: float, name_padding_width: int, value_padding_width: int, comment: str) -> None: ...

class CConfigFileMemory(CConfigFileBase):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, stringList: List[str]) -> None: ...
    @overload
    def __init__(self, str: str) -> None: ...
    @overload
    def __init__(self, arg0: CConfigFileMemory) -> None: ...
    @overload
    def __init__(self, arg0: CConfigFileMemory) -> None: ...
    def assign(self) -> CConfigFileMemory: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    @overload
    def getAllKeys(self, section: str, keys: List[str]) -> None: ...
    @overload
    def getAllKeys(conststd, classstd) -> void: ...
    @overload
    def getAllSections(self, sections: List[str]) -> None: ...
    @overload
    def getAllSections(classstd) -> void: ...
    @overload
    def getContent(self, str: str) -> None: ...
    @overload
    def getContent(std) -> void: ...
    @overload
    def getContent(self) -> str: ...
    @overload
    def setContent(self, stringList: List[str]) -> None: ...
    @overload
    def setContent(constclassstd) -> void: ...
    @overload
    def setContent(self, str: str) -> None: ...
    @overload
    def setContent(conststd) -> void: ...

class CConfigFilePrefixer(CConfigFileBase):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, o: CConfigFileBase, prefix_sections: str, prefix_keys: str) -> None: ...
    @overload
    def __init__(self, arg0: CConfigFilePrefixer) -> None: ...
    @overload
    def __init__(self, arg0: CConfigFilePrefixer) -> None: ...
    def assign(self) -> CConfigFilePrefixer: ...
    @overload
    def bind(self, o: CConfigFileBase) -> None: ...
    @overload
    def bind(constclassmrpt) -> void: ...
    @overload
    def clear(self) -> None: ...
    @overload
    def clear() -> void: ...
    @overload
    def getAllKeys(self, section: str, keys: List[str]) -> None: ...
    @overload
    def getAllKeys(conststd, classstd) -> void: ...
    @overload
    def getAllSections(self, sections: List[str]) -> None: ...
    @overload
    def getAllSections(classstd) -> void: ...
    def getBoundConfigFileBase(self) -> CConfigFileBase: ...
    def getKeyPrefix(self) -> str: ...
    def getSectionPrefix(self) -> str: ...
    def setPrefixes(self, prefix_sections: str, prefix_keys: str) -> None: ...

class CLoadableOptions:
    @overload
    def __init__(self, arg0: CLoadableOptions) -> None: ...
    @overload
    def __init__(self) -> None: ...
    def assign(self) -> CLoadableOptions: ...
    @overload
    def dumpToConsole(self) -> None: ...
    @overload
    def dumpToConsole() -> void: ...
    @overload
    def loadFromConfigFile(self, source, section: str) -> None: ...
    @overload
    def loadFromConfigFile(constclassmrpt, conststd) -> void: ...
    def loadFromConfigFileName(self, config_file: str, section: str) -> None: ...
    @overload
    def saveToConfigFile(self, target, section: str) -> None: ...
    @overload
    def saveToConfigFile(classmrpt, conststd) -> void: ...
    def saveToConfigFileName(self, config_file: str, section: str) -> None: ...

@overload
def MRPT_SAVE_NAME_PADDING() -> int: ...
@overload
def MRPT_SAVE_NAME_PADDING() -> int: ...
@overload
def MRPT_SAVE_VALUE_PADDING() -> int: ...
@overload
def MRPT_SAVE_VALUE_PADDING() -> int: ...
def config_parser(input: str) -> str: ...
